@@ -81,7 +81,7 @@ void DialogBox::create()
 
 
 // Show window such that the cursor is in it
-void DialogBox::show()
+void DialogBox::show(FXuint placement)
 {
     FXint rw,rh,wx,wy,ww,wh,x,y;
     FXuint state;
@@ -126,7 +126,7 @@ void DialogBox::show()
     }
 
     // Pop the window
-    FXTopWindow::show(PLACEMENT_CURSOR);
+    FXTopWindow::show(placement);
 }
 
 
@@ -151,9 +151,10 @@ long DialogBox::onKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 }
 
 // Execute dialog box modally
-FXuint DialogBox::execute()
+FXuint DialogBox::execute(FXuint placement)
 {
     create();
-    show();
+    show(placement);
     return getApp()->runModalFor(this);
 }
+
