@@ -26,9 +26,9 @@ public:
     };
 public:
     DialogBox(FXWindow* win,const FXString& name,FXuint opts=DECOR_TITLE|DECOR_BORDER,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=10,FXint pr=10,FXint pt=10,FXint pb=10,FXint hs=4,FXint vs=4);
-    virtual void show();
+    virtual void show(FXuint placement=PLACEMENT_CURSOR);
     virtual void create();
-    FXuint execute();
+    FXuint execute(FXuint placement=PLACEMENT_CURSOR);
     FXuint getOption();
 protected:
     FXuint _option;
