@@ -3,8 +3,8 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/FXPNGIcon.h>
 #if defined(linux)
 #include <mntent.h>
 #endif
@@ -18,9 +18,9 @@
 #include "MessageBox.h"
 
 
-// Interval between updevices and mtdevices read (ms)
-#define UPDEVICES_INTERVAL		65000
-#define MTDEVICES_INTERVAL		1000
+// Interval between updevices and mtdevices read (s)
+#define UPDEVICES_INTERVAL		300
+#define MTDEVICES_INTERVAL		5
 
 // Interval between refreshes (ms)
 #define REFRESH_INTERVAL     1000
@@ -41,6 +41,7 @@ extern FXStringDict* updevices;
 #endif
 
 
+
 // Object implementation
 FXIMPLEMENT(DirItem,FXTreeItem,NULL,0)
 
@@ -74,9 +75,6 @@ FXDEFMAP(DirList) DirListMap[]={
                                    FXMAPFUNC(SEL_UPDATE,DirList::ID_TOGGLE_FILES,DirList::onUpdToggleFiles),
                                    FXMAPFUNC(SEL_UPDATE,DirList::ID_SET_PATTERN,DirList::onUpdSetPattern),
                                    FXMAPFUNC(SEL_UPDATE,DirList::ID_SORT_REVERSE,DirList::onUpdSortReverse),
-                                   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_SETVALUE,DirList::onCmdSetValue),
-                                   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_SETSTRINGVALUE,DirList::onCmdSetStringValue),
-                                   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_GETSTRINGVALUE,DirList::onCmdGetStringValue),
                                    FXMAPFUNC(SEL_COMMAND,DirList::ID_SHOW_HIDDEN,DirList::onCmdShowHidden),
                                    FXMAPFUNC(SEL_COMMAND,DirList::ID_HIDE_HIDDEN,DirList::onCmdHideHidden),
                                    FXMAPFUNC(SEL_COMMAND,DirList::ID_TOGGLE_HIDDEN,DirList::onCmdToggleHidden),
@@ -92,35 +90,12 @@ FXDEFMAP(DirList) DirListMap[]={
 FXIMPLEMENT(DirList,FXTreeList,DirListMap,ARRAYNUMBER(DirListMap))
 
 
-// For serialization
-DirList::DirList()
-{
-    flags|=FLAG_ENABLED|FLAG_DROPTARGET;
-    counter=0;
-    matchmode=0;
-    associations=NULL;
-    dropaction=DRAG_MOVE;
-    sortfunc=(FXTreeListSortFunc)ascendingCase;
-    list=NULL;
-}
-
 
 // Directory List Widget
 DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
         FXTreeList(p,tgt,sel,opts,x,y,w,h),pattern("*")
 {
     flags|=FLAG_ENABLED|FLAG_DROPTARGET;
-    open_folder=new FXPNGIcon(getApp(),minifolderopen);
-    closed_folder=new FXPNGIcon(getApp(),minifolderclosed);
-    mini_doc=new FXPNGIcon(getApp(),minidoc);
-    mini_app=new FXPNGIcon(getApp(),miniapp);
-    locked_folder=new FXPNGIcon(getApp(),minifolderlocked);
-    harddiskicon=new FXPNGIcon(getApp(),harddisk);
-    nfsicon=new FXPNGIcon(getApp(),nfsdrive);
-    floppyicon=new FXPNGIcon(getApp(),floppy);
-    cdromicon=new FXPNGIcon(getApp(),cdrom);
-    zipicon=new FXPNGIcon(getApp(),zip);
-    linkicon=new FXPNGIcon(getApp(),minilink);
     matchmode=FILEMATCH_FILE_NAME|FILEMATCH_NOESCAPE;
     associations=NULL;
     if(!(options&DIRLIST_NO_OWN_ASSOC))
@@ -144,7 +119,8 @@ DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x
         {
             while((mnt=getmntent(fstab)))
             {
-                if(!::streq(mnt->mnt_type,MNTTYPE_IGNORE) && !::streq(mnt->mnt_type,MNTTYPE_SWAP) && !::streq(mnt->mnt_type,"proc") && !::streq(mnt->mnt_dir,"/"))
+                if(!::streq(mnt->mnt_type,MNTTYPE_IGNORE) && !::streq(mnt->mnt_type,MNTTYPE_SWAP) 
+					&& !::streq(mnt->mnt_type,"proc") && !::streq(mnt->mnt_dir,"/"))
                 {
                     if(!strncmp(mnt->mnt_fsname,"/dev/fd",7))
                         fsdevices->insert(mnt->mnt_dir,"floppy");
@@ -171,7 +147,11 @@ DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x
         if(mtab)
         {
             while((mnt=getmntent(mtab)))
-                mtdevices->insert(mnt->mnt_dir,mnt->mnt_type);
+			{
+				// To fix an issue with some Linux distributions
+				if (!::streq(mnt->mnt_dir,"/dev/.static/dev"))
+					mtdevices->insert(mnt->mnt_dir,mnt->mnt_type);
+			}
             endmntent(mtab);
         }
     }
@@ -186,11 +166,15 @@ DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x
         {
             while((mnt=getmntent(mtab)))
             {
-                if (mtlstat(mnt->mnt_dir,&statbuf)==-1)
-                    mtstate="down";
-                else
-                    mtstate="up";
-                updevices->insert(mnt->mnt_dir,mtstate.text());
+				// To fix an issue with some Linux distributions
+ 				if (!::streq(mnt->mnt_dir,"/dev/.static/dev"))
+				{
+					if (lstatmt(mnt->mnt_dir,&statbuf)==-1)
+						mtstate="down";
+					else
+						mtstate="up";
+					updevices->insert(mnt->mnt_dir,mtstate.text());
+				}
             }
             endmntent(mtab);
         }
@@ -210,21 +194,10 @@ void DirList::create()
         urilistType=getApp()->registerDragType(urilistTypeName);
     getApp()->addTimeout(this,ID_REFRESH_TIMER,REFRESH_INTERVAL);
 #if defined(linux)
-    getApp()->addTimeout(this,ID_MTDEVICES_REFRESH,MTDEVICES_INTERVAL);
-    getApp()->addTimeout(this,ID_UPDEVICES_REFRESH,UPDEVICES_INTERVAL);
+    getApp()->addTimeout(this,ID_MTDEVICES_REFRESH,MTDEVICES_INTERVAL*1000);
+    getApp()->addTimeout(this,ID_UPDEVICES_REFRESH,UPDEVICES_INTERVAL*1000);
 #endif
     dropEnable();
-    open_folder->create();
-    closed_folder->create();
-    mini_doc->create();
-    mini_app->create();
-    locked_folder->create();
-    harddiskicon->create();
-    nfsicon->create();
-    floppyicon->create();
-    cdromicon->create();
-    zipicon->create();
-    linkicon->create();
 
     // Scan root directory
     scan(FALSE);
@@ -399,6 +372,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
     FXuchar *data;
     FXuint len;
     FXbool showdialog=TRUE;
+	FXbool ret;
     File *f=NULL;
 
     FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
@@ -430,7 +404,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
         
 		// Number of selected items
 		FXString buf=p;
-        int num=buf.count('\n')+1;
+        int num=buf.contains('\n')+1;
 		
 		// Eventually correct the number of selected items
 		// because sometimes there is another '\n' at the end of the string
@@ -447,7 +421,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
             f=new File(this,_("File symlink"),SYMLINK);
         else if ((dropaction==DRAG_LINK) && (num>1))
 		{
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Can't symlink multiple selection!"));
+			MessageBox::error(this,BOX_OK,_("Error"),_("Can't symlink multiple selection!"));
 			return 0;
 		}
 		else
@@ -459,9 +433,9 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
                 q++;
             FXString url(p,q-p);
             FXString source(FXURL::fileFromURL(url));
-            FXString target(dropdirectory+PATHSEPSTRING+FXFile::name(source));
-            FXString sourcedir=FXFile::directory(source);
-            FXString targetdir=FXFile::directory(target);
+            FXString target(dropdirectory+PATHSEPSTRING+FXPath::name(source));
+            FXString sourcedir=FXPath::directory(source);
+            FXString targetdir=FXPath::directory(target);
 
             // File operation dialog, if needed
             if(ask_before_copy & showdialog)
@@ -471,7 +445,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
                 if (dropaction==DRAG_COPY)
                 {
                     title=_("Copy ");
-                    icon = new FXPNGIcon(getApp(),copy_big);
+                    icon = copy_bigicon;
                     if (num==1)
                         message=title+source;
                     else
@@ -480,7 +454,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
                 else if (dropaction==DRAG_MOVE)
                 {
                     title=_("Move ");
-                    icon = new FXPNGIcon(getApp(),move_big);
+                    icon = move_bigicon;
                     if (num==1)
                         message=title+source;
                     else
@@ -489,7 +463,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
                 else if ((dropaction==DRAG_LINK) && (num==1))
                 {
                     title=_("Symlink ");
-                    icon=new FXPNGIcon(getApp(),link_big);
+                    icon=link_bigicon;
 					message=title+source;
                 }
 
@@ -502,7 +476,6 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
                 if (num>1)
                     showdialog=FALSE;
                 delete dialog;
-                delete icon;
                 if (!rc)
                     return 0;
             }
@@ -512,13 +485,20 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
             {
                 // Move file
                 f->create();
-                f->move(source,target);
+                ret=f->move(source,target);
 
-                // If action is cancelled in progress dialog
+ 				// An error has occurred
+				if (ret==0 && !f->isCancelled)
+				{
+					f->hide();
+					MessageBox::error(this,BOX_OK,_("Error"),_("An error has occurred during the move file operation!"));
+				}
+
+				// If action is cancelled in progress dialog
                 if (f->isCancelled)
                 {
                     f->hide();
-                    MessageBox::error(this,MBOX_OK,_("Error"),_("Move file operation cancelled!"));
+                    MessageBox::error(this,BOX_OK,_("Error"),_("Move file operation cancelled!"));
                 }
             }
             // Copy the source file
@@ -526,13 +506,20 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
             {
                 // Copy file
                 f->create();
-                f->copy(source,target);
+                ret=f->copy(source,target);
 
+				// An error has occurred
+				if (ret==0 && !f->isCancelled)
+				{
+					f->hide();
+					MessageBox::error(this,BOX_OK,_("Error"),_("An error has occurred during the copy file operation!"));
+				}
+					
                 // If action is cancelled in progress dialog
                 if (f->isCancelled)
                 {
                     f->hide();
-                    MessageBox::error(this,MBOX_OK,_("Error"),_("Copy file operation cancelled!"));
+                    MessageBox::error(this,BOX_OK,_("Error"),_("Copy file operation cancelled!"));
                 }
             }
             // Link the source file (no progress dialog in this case)
@@ -659,33 +646,6 @@ long DirList::onDragged(FXObject* sender,FXSelector sel,void* ptr)
 }
 
 
-// Open up the path down to the given string
-long DirList::onCmdSetValue(FXObject*,FXSelector,void* ptr)
-{
-    if(ptr)
-        setCurrentFile((const FXchar*)ptr);
-    return 1;
-}
-
-
-// Open up the path down to the given string
-long DirList::onCmdSetStringValue(FXObject*,FXSelector,void* ptr)
-{
-    if(ptr)
-        setCurrentFile(*((FXString*)ptr));
-    return 1;
-}
-
-
-// Obtain value of the current item
-long DirList::onCmdGetStringValue(FXObject*,FXSelector,void* ptr)
-{
-    if(ptr)
-        *((FXString*)ptr)=getCurrentFile();
-    return 1;
-}
-
-
 // Toggle hidden files
 long DirList::onCmdToggleHidden(FXObject*,FXSelector,void*)
 {
@@ -931,7 +891,6 @@ FXbool DirList::expandTree(TreeItem* tree,FXbool notify)
     {
         if(isItemDirectory(tree))
         {
-            FXTRACE((10,"expandTree: %s pathname=%s\n",tree->getText().text(),getItemPathname(tree).text()));
             listChildItems((DirItem*)tree);
             sortChildItems(tree);
         }
@@ -948,7 +907,6 @@ FXbool DirList::collapseTree(TreeItem* tree,FXbool notify)
     {
         if(isItemDirectory(tree))
         {
-            FXTRACE((10,"collapseTree: %s path=%s\n",tree->getText().text(),getItemPathname(tree).text()));
             // As a memory saving feature, all knowledge below this item
             // is deleted; we'll just recreate it when its reexpanded!
             //removeItems(item->first,item->last);
@@ -972,11 +930,14 @@ long DirList::onMtdevicesRefresh(FXObject*,FXSelector,void*)
     {
         while((mnt=getmntent(mtab)))
         {
-            tmpdict->insert(mnt->mnt_dir,"");
-            if (mtdevices->find(mnt->mnt_dir))
-                mtdevices->remove
-                (mnt->mnt_dir);
-            mtdevices->insert(mnt->mnt_dir,mnt->mnt_type);
+			// To fix an issue with some Linux distributions
+			if (!::streq(mnt->mnt_dir,"/dev/.static/dev"))
+			{
+				tmpdict->insert(mnt->mnt_dir,"");
+				if (mtdevices->find(mnt->mnt_dir))
+					mtdevices->remove(mnt->mnt_dir);
+				mtdevices->insert(mnt->mnt_dir,mnt->mnt_type);
+			}
         }
         endmntent(mtab);
     }
@@ -989,13 +950,12 @@ long DirList::onMtdevicesRefresh(FXObject*,FXSelector,void*)
         key = mtdevices->key(s);
         data = mtdevices->data(s);
         if (!tmpdict->find(mtdevices->key(s)))
-            mtdevices->remove
-            (mtdevices->key(s));
+            mtdevices->remove(mtdevices->key(s));
     }
     delete tmpdict;
 
     // Reset timer again
-    getApp()->addTimeout(this,ID_MTDEVICES_REFRESH,MTDEVICES_INTERVAL);
+    getApp()->addTimeout(this,ID_MTDEVICES_REFRESH,MTDEVICES_INTERVAL*1000);
     return 0;
 }
 
@@ -1016,21 +976,24 @@ long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
     {
         while((mnt=getmntent(mtab)))
         {
-            tmpdict->insert(mnt->mnt_dir,"");
+			// To fix an issue with some Linux distributions
+			if (!::streq(mnt->mnt_dir,"/dev/.static/dev"))
+			{
+				tmpdict->insert(mnt->mnt_dir,"");
 
-            if (mtlstat(mnt->mnt_dir,&statbuf)==-1)
-            {
-                mtstate="down";
-                if (mount_warn)
-                    MessageBox::warning(this,MBOX_OK,_("Warning"),_("Mount point %s is not responding..."),mnt->mnt_dir);
-            }
-            else
-                mtstate="up";
+				if (lstatmt(mnt->mnt_dir,&statbuf)==-1)
+				{
+					mtstate="down";
+					if (mount_warn)
+						MessageBox::warning(this,BOX_OK,_("Warning"),_("Mount point %s is not responding..."),mnt->mnt_dir);
+				}
+				else
+					mtstate="up";
 
-            if (updevices->find(mnt->mnt_dir))
-                updevices->remove
-                (mnt->mnt_dir);
-            updevices->insert(mnt->mnt_dir,mtstate.text());
+				if (updevices->find(mnt->mnt_dir))
+					updevices->remove(mnt->mnt_dir);
+				updevices->insert(mnt->mnt_dir,mtstate.text());
+			}
 
         }
         endmntent(mtab);
@@ -1044,14 +1007,13 @@ long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
         key = updevices->key(s);
         data = updevices->data(s);
         if (!tmpdict->find(updevices->key(s)))
-            updevices->remove
-            (updevices->key(s));
+            updevices->remove(updevices->key(s));
 
     }
     delete tmpdict;
 
     // Reset timer again
-    getApp()->addTimeout(this,ID_UPDEVICES_REFRESH,UPDEVICES_INTERVAL);
+    getApp()->addTimeout(this,ID_UPDEVICES_REFRESH,UPDEVICES_INTERVAL*1000);
     return 0;
 }
 #endif
@@ -1103,7 +1065,7 @@ void DirList::scan(FXbool force)
             pathname=getItemPathname((TreeItem*)item);
 
             // Stat this directory; should not fail as parent has been scanned already
-			statout(pathname.text(),&info);
+			statrep(pathname.text(),&info);
 
             // Get the mod date of the item
             FXTime newdate=(FXTime)FXMAX(info.st_mtime,info.st_ctime);
@@ -1247,16 +1209,16 @@ void DirList::listChildItems(DirItem *par)
             pathname+=name;
 
             // Get file/link info
-			if(lstatout(pathname.text(),&info)!=0)
+			if(lstatrep(pathname.text(),&info)!=0)
                 continue;
 
             // If its a link, get the info on file itself
             islink=S_ISLNK(info.st_mode);
-			if(islink && statout(pathname.text(),&info)!=0)
+			if(islink && statrep(pathname.text(),&info)!=0)
                 continue;
 
             // If it is not a directory, and not showing files and matching pattern skip it
-            if(!S_ISDIR(info.st_mode) && !((options&DIRLIST_SHOWFILES) && FXFile::match(pattern,name,matchmode)))
+            if(!S_ISDIR(info.st_mode) && !((options&DIRLIST_SHOWFILES) && FXPath::match(pattern,name,matchmode)))
                 continue;
 
             // Find it, and take it out from the old list if found
@@ -1272,7 +1234,7 @@ void DirList::listChildItems(DirItem *par)
             }
 
             // Not found; prepend before list
-            item=(DirItem*)appendItem(par,name,open_folder,closed_folder,NULL,TRUE);
+            item=(DirItem*)appendItem(par,name,minifolderopenicon,minifolderclosedicon,NULL,TRUE);
 
             // Next gets hung after this one
 fnd:
@@ -1353,28 +1315,28 @@ fnd:
             {
                 if(!::isReadExecutable(pathname))
                 {
-                    openicon=locked_folder;
-                    closedicon=locked_folder;
+                    openicon=minifolderopenicon;
+                    closedicon=minifolderlockedicon;
                 }
                 else
                 {
-                    openicon=open_folder;
-                    closedicon=closed_folder;
+                    openicon=minifolderopenicon;
+                    closedicon=minifolderclosedicon;
                 }
                 if(associations)
                     fileassoc=associations->findDirBinding(pathname.text());
             }
             else if(item->state&DirItem::EXECUTABLE)
             {
-                openicon=mini_app;
-                closedicon=mini_app;
+                openicon=miniappicon;
+                closedicon=miniappicon;
                 if(associations)
                     fileassoc=associations->findExecBinding(pathname.text());
             }
             else
             {
-                openicon=mini_doc;
-                closedicon=mini_doc;
+                openicon=minidocicon;
+                closedicon=minidocicon;
                 if(associations)
                     fileassoc=associations->findFileBinding(pathname.text());
             }
@@ -1407,13 +1369,13 @@ fnd:
                 }
                 else if(::streq(fsdevices->find(pathname.text()),"nfsdisk"))
                 {
-                    item->closedIcon=nfsicon;
-                    item->openIcon=nfsicon;
+                    item->closedIcon=nfsdriveicon;
+                    item->openIcon=nfsdriveicon;
                 }
                 else if(::streq(fsdevices->find(pathname.text()),"smbdisk"))
                 {
-                    item->closedIcon=nfsicon;
-                    item->openIcon=nfsicon;
+                    item->closedIcon=nfsdriveicon;
+                    item->openIcon=nfsdriveicon;
                 }
                 else if(::streq(fsdevices->find(pathname.text()),"floppy"))
                 {
@@ -1436,8 +1398,8 @@ fnd:
             // Symbolic links have a specific icon
             if(islink)
             {
-                item->closedIcon=linkicon;
-                item->openIcon=linkicon;
+                item->closedIcon=minilinkicon;
+                item->openIcon=minilinkicon;
             }
 
             // Create item
@@ -1592,13 +1554,12 @@ FXString DirList::getItemFilename(const TreeItem* item) const
 // Open all intermediate directories down toward given one
 void DirList::setDirectory(const FXString& pathname,FXbool notify)
 {
-    FXTRACE((100,"%s::setDirectory(%s)\n",getClassName(),pathname.text()));
     if(!pathname.empty())
     {
-        FXString path=FXFile::absolute(getItemPathname((TreeItem*)currentitem),pathname);
-        while(!FXFile::isTopDirectory(path) && !FXFile::isDirectory(path))
+        FXString path=FXPath::absolute(getItemPathname((TreeItem*)currentitem),pathname);
+        while(!FXPath::isTopDirectory(path) && !::isDirectory(path))
         {
-            path=FXFile::upLevel(path);
+            path=FXPath::upLevel(path);
         }
         TreeItem *item=getPathnameItem(path);
         if(id())
@@ -1626,13 +1587,12 @@ FXString DirList::getDirectory() const
 // Set current (dir/file) name path
 void DirList::setCurrentFile(const FXString& pathname,FXbool notify)
 {
-    FXTRACE((100,"%s::setCurrentFile(%s)\n",getClassName(),pathname.text()));
     if(!pathname.empty())
     {
-        FXString path=FXFile::absolute(getItemPathname((TreeItem*)currentitem),pathname);
-        while(!FXFile::isTopDirectory(path) && !::exists(path))
+        FXString path=FXPath::absolute(getItemPathname((TreeItem*)currentitem),pathname);
+        while(!FXPath::isTopDirectory(path) && !::exists(path))
         {
-            path=FXFile::upLevel(path);
+            path=FXPath::upLevel(path);
         }
         TreeItem *item=getPathnameItem(path);
         if(id())
@@ -1741,26 +1701,7 @@ DirList::~DirList()
 #endif
     if(!(options&DIRLIST_NO_OWN_ASSOC))
         delete associations;
-    delete closed_folder;
-    delete open_folder;
-    delete mini_doc;
-    delete mini_app;
-    delete harddiskicon;
-    delete nfsicon;
-    delete floppyicon;
-    delete cdromicon;
-    delete zipicon;
-    delete linkicon;
-    delete locked_folder;
     associations=(FileDict*)-1;
-    closed_folder=(FXPNGIcon*)-1;
-    open_folder=(FXPNGIcon*)-1;
-    mini_doc=(FXPNGIcon*)-1;
-    mini_app=(FXPNGIcon*)-1;
-    harddiskicon=(FXPNGIcon*)-1;
-    nfsicon=(FXPNGIcon*)-1;
-    linkicon=(FXPNGIcon*)-1;
-    locked_folder=(FXPNGIcon*)-1;
 }
 
 
