@@ -33,6 +33,11 @@ extern FXStringDict* fsdevices;
 extern FXStringDict* mtdevices;
 #endif
 
+extern FXbool single_click_diropen;
+extern FXbool single_click_fileopen;
+
+
+
 // Map
 FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_EXPANDTREE,DirPanel::onExpandTree),
@@ -54,7 +59,6 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_COPY_CLP,DirPanel::onCmdClp),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_CUT_CLP,DirPanel::onCmdClp),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_PASTE_CLP,DirPanel::onCmdPaste),
-                                   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_SORT_REVERSE,DirPanel::onCmdSortReverse),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_HIDDEN,DirPanel::onCmdToggleHidden),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_TREE,DirPanel::onCmdToggleTree),
                                    FXMAPFUNC(SEL_TIMEOUT,DirPanel::ID_DIRSIZE_REFRESH,DirPanel::onCmdDirsizeRefresh),
@@ -105,6 +109,12 @@ DirPanel::DirPanel(FXComposite *p, FXColor listbackcolor, FXColor listforecolor,
     if(homelocation=="")
         homelocation=ROOTDIR;
 	trashlocation=homelocation+PATHSEPSTRING+TRASHPATH;
+
+	// Single click navigation
+    single_click_diropen=getApp()->reg().readUnsignedEntry("OPTIONS","single_click_diropen",FALSE);
+    single_click_fileopen=getApp()->reg().readUnsignedEntry("OPTIONS","single_click_fileopen",FALSE);
+	if (single_click_diropen & single_click_fileopen)
+		list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
 }
 
 
@@ -171,7 +181,18 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
        	}
        	if(i==count)
 			address->insertItem(0,currentpanel->list->getDirectory());
+
     }
+
+	// Manage single click navigation
+	if (item && single_click_diropen)
+	{
+		//if (item->isExpanded())
+			//list->handle(this,FXSEL(SEL_COLLAPSED,0),(void*)ptr);
+		//else
+			list->handle(this,FXSEL(SEL_EXPANDED,0),(void*)ptr);
+	}
+		
     return 1;
 }
 
@@ -221,7 +242,7 @@ long DirPanel::onPopupMenu(FXObject* o,FXSelector s,void* p)
 
 	// If no item under cursor, then return
 	if (item==NULL) return 0;
-	
+
 	// If item, then set it current and set directory in DirList and FileList
 	list->setCurrentItem(item,TRUE);
 	FXString dir=list->getItemPathname((TreeItem*)item);
@@ -258,7 +279,7 @@ long DirPanel::onPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuCommand(&menu,_("&Delete"),filedelete_permicon,this,DirPanel::ID_DIR_DELETE);
     new FXMenuSeparator(&menu);
 	new FXMenuCheck(&menu,_("&Hidden folders"),this,DirPanel::ID_TOGGLE_HIDDEN);
-	new FXMenuCommand(&menu,_("&Reverse order"),sorticon,this,DirPanel::ID_SORT_REVERSE);
+	new FXMenuCheck(&menu,_("&Reverse order"),list,DirList::ID_SORT_REVERSE);
 	new FXMenuCommand(&menu,_("E&xpand tree"),exptreeicon,this,DirPanel::ID_EXPANDTREE);
 	new FXMenuCommand(&menu,_("Collap&se tree"),colltreeicon,this,DirPanel::ID_COLLAPSETREE);
     new FXMenuSeparator(&menu);
@@ -507,13 +528,6 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void*)
     return 1;
 }
 
-// Reverse the sort order
-long DirPanel::onCmdSortReverse(FXObject* sender,FXSelector sel,void*)
-{
-        list->handle(this,FXSEL(SEL_COMMAND,DirList::ID_SORT_REVERSE),NULL);
-		return 1;
-}
-
 
 // Delete directory
 long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
@@ -784,7 +798,7 @@ long DirPanel::onCmdNewDir(FXObject*,FXSelector,void*)
 			FXint ret=::mkdir(dirname.text(),511 & ~mask);
 			if (ret==-1)
 			{
-         		MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno));
+         		MessageBox::error(this,BOX_OK_SU,_("Error"),"%s",strerror(errno));
     			return 0;
 			}
 		}							
