@@ -10,6 +10,7 @@ class DirPanel : public FXVerticalFrame
     friend class XFileExplorer;
 	friend class FilePanel;
 	friend class PathLinker;
+	friend class PreferencesBox;
 protected:
 	DirList	*list;
 	FXPacker *statusbar;
@@ -45,7 +46,6 @@ DirPanel(FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listfor
 		ID_PASTE_CLP,
         ID_TOGGLE_TREE,
 		ID_TITLE,
-		ID_SORT_REVERSE,
 		ID_DIRSIZE_REFRESH,
 #if defined(linux)
         ID_MOUNT,
@@ -83,7 +83,6 @@ public:
 	long onUpdTitle(FXObject*,FXSelector,void*);
 	long onUpdStatus(FXObject*,FXSelector,void*);
 	long onExpand(FXObject*,FXSelector,void*);
-	long onCmdSortReverse(FXObject*,FXSelector,void*);
 #if defined(linux)
 	long onCmdMount(FXObject*,FXSelector sel,void*);
 #endif
