@@ -19,6 +19,7 @@
 #include <unistd.h>
 #include <sys/wait.h>
 #include <time.h>
+#include <utime.h>
 
 // For Sun compatibility
 #ifdef __sun
@@ -349,15 +350,14 @@ FXString cleanPath(const FXString path)
 	FXString in=path, out=path;
 	while (1)
 	{
-		if (in[in.length()-1]=='/' & in.length()!=1)
+		if (in[in.length()-1]=='/' && in.length()!=1)
 		{
 			out=in.trunc(in.length()-1);
 			in=out;
 		}
 		else
 			break;
-	}
-
+	}	
 	return (out);
 }
 
@@ -370,7 +370,7 @@ FXString filePath(const FXString path)
 	FXString in=path, out=path;
 	while (1)
 	{
-		if (in[in.length()-1]=='/' & in.length()!=1)
+		if (in[in.length()-1]=='/' && in.length()!=1)
 		{
 			out=in.trunc(in.length()-1);
 			in=out;
@@ -938,11 +938,12 @@ long File::fullwrite(int fd,const unsigned char *ptr,long len)
 
 
 // Copy ordinary file
-FXbool File::copyfile(const FXString& source, const FXString& target)
+FXbool File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
 {
-    FXString destfile;
+	FXString destfile;
 	unsigned char buffer[4096];
     struct stat status;
+	struct utimbuf timbuf;
     long long nread,nwritten;
 	long long size, nread_all=0;
 	double pct=0;
@@ -1011,6 +1012,15 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
                 ok=TRUE;
 err:
                 ::close(dst);
+				
+				// Keep original date if asked
+				if (preserve_date)
+				{
+					timbuf.actime=status.st_atime;
+					timbuf.modtime=status.st_mtime;
+					if(utime(destfile.text(),&timbuf)==-1)
+						MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno) );
+				}
             }
         }
         ::close(src);
@@ -1020,11 +1030,12 @@ err:
 
 
 // Copy directory
-FXbool File::copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes)
+FXbool File::copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes, const FXbool preserve_date)
 {
     DIR *dirp;
     struct dirent *dp;
     struct stat status;
+	struct utimbuf timbuf;
     inodelist *in,inode;
     FXString destfile,oldchild,newchild;
 
@@ -1071,7 +1082,7 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
             if(!ISPATHSEP(newchild[newchild.length()-1]))
                 newchild.append(PATHSEP);
             newchild.append(dp->d_name);
-			if(!copyrec(oldchild,newchild,&inode))
+			if(!copyrec(oldchild,newchild,&inode,preserve_date))
             {
 				// If the cancel button was pressed
 				if (isCancelled)
@@ -1104,13 +1115,25 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
     // Close directory
     closedir(dirp);
 
+	// Keep original date if asked
+	if (preserve_date)
+	{
+		if(lstatrep(source.text(),&status)==0)
+		{
+			timbuf.actime=status.st_atime;
+			timbuf.modtime=status.st_mtime;
+			if(utime(destfile.text(),&timbuf)==-1)
+				MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno) );
+		}
+	}
+	
     // Success
     return TRUE;
 }
 
 
 // Recursive copy
-FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* inodes)
+FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date)
 {
     struct stat status1,status2;
 
@@ -1139,11 +1162,11 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
 		
 	// Source is directory: copy recursively
     if(S_ISDIR(status1.st_mode))
-        return File::copydir(source,target,status1,inodes);
+        return File::copydir(source,target,status1,inodes,preserve_date);
 
     // Source is regular file: copy block by block
     if(S_ISREG(status1.st_mode))
-        return File::copyfile(source,target);
+        return File::copyfile(source,target,preserve_date);
 
     // Source is fifo: make a new one
     if(S_ISFIFO(status1.st_mode))
@@ -1167,7 +1190,7 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
 
 
 // Copy file
-FXbool File::copy(const FXString& source, const FXString& target, const FXbool confirm_dialog)
+FXbool File::copy(const FXString& source, const FXString& target, const FXbool confirm_dialog, const FXbool preserve_date)
 {
 	FXString targetfile;
 
@@ -1243,7 +1266,7 @@ FXbool File::copy(const FXString& source, const FXString& target, const FXbool c
 	}
 
 	// Copy file or directory
-	return File::copyrec(source,targetfile,NULL);
+	return File::copyrec(source,targetfile,NULL,preserve_date);
 }
 
 
@@ -1406,8 +1429,8 @@ FXbool File::rename(const FXString& source, const FXString& target)
 		return FALSE;
 	}
 
-	// If files are on different file systems, use the copy/delete scheme
-	FXbool ret=this->copy(source,target,FALSE);
+	// If files are on different file systems, use the copy/delete scheme and preserve the original date
+	FXbool ret=this->copy(source,target,FALSE,TRUE);
 	if (ret)
 		return (remove(source.text())==TRUE);
 	else
@@ -1505,8 +1528,8 @@ FXbool File::move(const FXString& source,const FXString& target)
 		return FALSE;
 	}
 
-	// If files are on different file systems, use the copy/delete scheme
-	FXbool ret=this->copy(source,targetfile,FALSE);
+	// If files are on different file systems, use the copy/delete scheme and preserve the original date
+	FXbool ret=this->copy(source,targetfile,FALSE,TRUE);
 	if (ret)
 		return (remove(source.text())==TRUE);
 	else
