@@ -79,9 +79,9 @@ protected:
 	int checkTimeout(void);
     long fullread(int fd, unsigned char *ptr, long len);
     long fullwrite(int fd, const unsigned char *ptr, long len);
-    FXbool copyfile(const FXString& source, const FXString& target);
-	FXbool copyrec(const FXString& source,const FXString& target,inodelist* inodes);
-    FXbool copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes);
+    FXbool copyfile(const FXString& source, const FXString& target, const FXbool preserve_date);
+	FXbool copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date);
+    FXbool copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes, const FXbool preserve_date);
     int rchmod(char *path, char *file, mode_t mode, const FXbool dironly, const FXbool fileonly);
     int rchown(char *path, char *file, uid_t uid, gid_t gid, const FXbool dironly, const FXbool fileonly);
     FXLabel *uplabel;
@@ -108,7 +108,7 @@ public:
 
 	FXbool allowPdialog;
 	FXbool isCancelled;
-    FXbool copy(const FXString& source, const FXString& target, const FXbool confirm_dialog=TRUE);
+    FXbool copy(const FXString& source, const FXString& target, const FXbool confirm_dialog=TRUE, const FXbool preserve_date=TRUE);
     FXbool rename(const FXString& source, const FXString& target);
     FXbool move(const FXString& source, const FXString& target);
     FXbool symlink(const FXString& source, const FXString& target);
