@@ -11,17 +11,23 @@
 #include "DirBox.h"
 #include "FileDialog.h"
 #include "DirHistBox.h"
+#include "MessageBox.h"
 #include "icons.h"
 
 #define FILELISTMASK (ICONLIST_EXTENDEDSELECT|ICONLIST_SINGLESELECT|ICONLIST_BROWSESELECT|ICONLIST_MULTIPLESELECT)
 
+// Single click navigation
+extern FXbool single_click_diropen;
+extern FXbool single_click_fileopen;
+
 
 
 // Map
 FXDEFMAP(FileSelector) FileSelectorMap[]={
             FXMAPFUNC(SEL_COMMAND,FileSelector::ID_ACCEPT,FileSelector::onCmdAccept),
             FXMAPFUNC(SEL_COMMAND,FileSelector::ID_FILEFILTER,FileSelector::onCmdFilter),
-            FXMAPFUNC(SEL_DOUBLECLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDblClicked),
+            FXMAPFUNC(SEL_DOUBLECLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDoubleClicked),
+            FXMAPFUNC(SEL_CLICKED,FileSelector::ID_FILELIST,FileSelector::onCmdItemClicked),
             FXMAPFUNC(SEL_SELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemSelected),
             FXMAPFUNC(SEL_DESELECTED,FileSelector::ID_FILELIST,FileSelector::onCmdItemDeselected),
             FXMAPFUNC(SEL_COMMAND,FileSelector::ID_DIR_UP,FileSelector::onCmdDirUp),
@@ -102,11 +108,15 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     setDirectory(FXSystem::getCurrentDirectory());
     filebox->setFocus();
     accept->hide();
+
+	// Change default cursor if single click navigation
+	if (single_click_diropen & single_click_fileopen)
+		filebox->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
 }
 
 
 // Double-clicked item in file list
-long FileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr)
+long FileSelector::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
 {
     FXint index=(FXint)(long)ptr;
     if(index<0)
@@ -115,7 +125,16 @@ long FileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr)
     // If directory, open the directory
     if(filebox->isItemDirectory(index))
     {
-        setDirectory(filebox->getItemPathname(index));
+		FXString filepath=filebox->getItemPathname(index);
+
+		// Does not have access
+		if(!::isReadExecutable(filepath))
+		{
+			MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+			return 0;
+		}
+		
+        setDirectory(filepath);
         return 1;
     }
 
@@ -134,6 +153,41 @@ long FileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr)
 }
 
 
+// Single clicked item in file list
+long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
+{
+	if (single_click_diropen | single_click_fileopen)
+	{		
+		FXint index=(FXint)(long)ptr;
+		if(index<0)
+			return 1;
+
+		// If directory, open the directory
+		if(single_click_diropen && filebox->isItemDirectory(index))
+		{
+			FXString filepath=filebox->getItemPathname(index);
+
+			// Does not have access
+			if(!::isReadExecutable(filepath))
+			{
+				MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+				return 0;
+			}
+			
+			setDirectory(filepath);
+			return 1;
+		}
+		else if(single_click_fileopen && filebox->isItemFile(index))
+		{
+			FXObject *tgt=accept->getTarget();
+			FXSelector sel=accept->getSelector();
+			if(tgt)
+				tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
+		}
+	}
+    return 1;
+}
+
 // Change in items which are selected
 long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
 {
