@@ -34,7 +34,8 @@ private:
 public:
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdFilter(FXObject*,FXSelector,void*);
-    long onCmdItemDblClicked(FXObject*,FXSelector,void*);
+    long onCmdItemDoubleClicked(FXObject*,FXSelector,void*);
+    long onCmdItemClicked(FXObject*,FXSelector,void*);
     long onCmdItemSelected(FXObject*,FXSelector,void*);
     long onCmdItemDeselected(FXObject*,FXSelector,void*);
     long onCmdDirUp(FXObject*,FXSelector,void*);
