@@ -126,7 +126,9 @@ protected:
 	FXbool		allowrefresh;			// Allow or disallow periodic refresh
 	FXbool		displaythumbnails;		// Display thumbnails
 	FXColor 	*tmpdata;				// Temporary image data
-	FXString	trashlocation;
+	FXString	trashlocation;          // Location of the trash directory
+	FXbool      single;                 // Allow single click navigation for directories
+	FXbool		dirsfirst;				// Sort directories first
 
 public:
 	StringList		*backhist;          // Back history
@@ -188,6 +190,9 @@ public:
 	long onUpdHeader(FXObject*,FXSelector,void*);
 	long onCmdToggleThumbnails(FXObject*,FXSelector,void*);
 	long onUpdToggleThumbnails(FXObject* sender,FXSelector,void*);
+	long onCmdDirsFirst(FXObject*,FXSelector,void*);
+	long onUpdDirsFirst(FXObject*,FXSelector,void*);
+	
 public:
 	static FXint ascending(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint descending(const FXIconItem* pa,const FXIconItem* pb);
@@ -209,6 +214,27 @@ public:
 	static FXint descendingPerm(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint ascendingDeltime(const FXIconItem* pa,const FXIconItem* pb);
 	static FXint descendingDeltime(const FXIconItem* pa,const FXIconItem* pb);
+
+	static FXint ascendingMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingCaseMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingCaseMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingTypeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingTypeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingSizeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingSizeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingExtMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingExtMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingTimeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingTimeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingUserMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingUserMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingGroupMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingGroupMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingPermMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingPermMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint ascendingDeltimeMix(const FXIconItem* pa,const FXIconItem* pb);
+	static FXint descendingDeltimeMix(const FXIconItem* pa,const FXIconItem* pb);
 public:
 	enum {
 		// Note : the order of the 9 following sort IDs must be kept
@@ -223,6 +249,7 @@ public:
         ID_SORT_BY_DELTIME,
         ID_SORT_REVERSE,
     	ID_SORT_CASE,
+    	ID_DIRS_FIRST,
         ID_DIRECTORY_UP,
         ID_SET_PATTERN,
         ID_SET_DIRECTORY,
@@ -315,6 +342,18 @@ public:
 		ignorecase=icase;
 	}
 
+	// Return directory first state for file name sorting
+	FXbool getDirsFirst() const
+	{
+		return dirsfirst;
+	}
+
+	// Set directory first state for file name sorting
+	void setDirsFirst(const FXbool dfirst)
+	{
+		dirsfirst=dfirst;
+	}
+
 	// Allow or disallow periodic refresh
 	void setAllowRefresh(const FXbool allow);
 
