@@ -42,6 +42,8 @@ extern FXbool rpm_based;
 
 FXuint clptype=0;
 extern FXbool allowPopupScroll;
+extern FXbool single_click_diropen;
+extern FXbool single_click_fileopen;
 
 
 
@@ -81,10 +83,11 @@ FXDEFMAP(FilePanel) FilePanelMap[]={
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_ADD_TO_ARCH,FilePanel::onCmdAddToArch),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_EXTRACT,FilePanel::onCmdExtract),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_EXTRACT_HERE,FilePanel::onCmdExtractHere),
-                               FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,FilePanel::ID_FILE_PANEL,FilePanel::onCmdPopupMenu),
+                               FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,FilePanel::ID_FILELIST,FilePanel::onCmdPopupMenu),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_MENU,FilePanel::onCmdPopupMenu),
-                               FXMAPFUNC(SEL_DOUBLECLICKED,FilePanel::ID_FILE_PANEL,FilePanel::onCmdItemDblClcked),
-                               FXMAPFUNC(SEL_FOCUSIN,FilePanel::ID_FILE_PANEL,FilePanel::onCmdItemClcked),
+                               FXMAPFUNC(SEL_DOUBLECLICKED,FilePanel::ID_FILELIST,FilePanel::onCmdItemDoubleClicked),
+                               FXMAPFUNC(SEL_CLICKED,FilePanel::ID_FILELIST,FilePanel::onCmdItemClicked),
+                               FXMAPFUNC(SEL_FOCUSIN,FilePanel::ID_FILELIST,FilePanel::onCmdItemFocus),
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_STATUS,FilePanel::onUpdStatus),
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_DIRECTORY_UP,FilePanel::onUpdUp),
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_COPY_CLP,FilePanel::onUpdMenu),
@@ -108,7 +111,7 @@ FXDEFMAP(FilePanel) FilePanelMap[]={
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_TOGGLE_HIDDEN,FilePanel::onUpdToggleHidden),
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_TOGGLE_THUMBNAILS,FilePanel::onUpdToggleThumbnails),
  #if defined(linux)
-                              FXMAPFUNC(SEL_COMMAND,FilePanel::ID_MOUNT,FilePanel::onCmdMount),
+                               FXMAPFUNC(SEL_COMMAND,FilePanel::ID_MOUNT,FilePanel::onCmdMount),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_UMOUNT,FilePanel::onCmdMount),
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_MOUNT,FilePanel::onUpdMount),
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_UMOUNT,FilePanel::onUpdUnmount),
@@ -134,7 +137,7 @@ FilePanel::FilePanel(FXchar* nm,FXComposite *p, FXuint name_size, FXuint size_si
 
     pathlink = new PathLinker(cont);
 
-    list=new FileList(cont,this,ID_FILE_PANEL,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE);
+    list=new FileList(cont,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE);
 	
 	list->setHeaderSize(0,name_size);
     list->setHeaderSize(1,size_size);
@@ -163,6 +166,12 @@ FilePanel::FilePanel(FXchar* nm,FXComposite *p, FXuint name_size, FXuint size_si
 	selmult=FALSE;
 	current=NULL;
     
+	// Single click navigation
+    single_click_diropen=getApp()->reg().readUnsignedEntry("OPTIONS","single_click_diropen",FALSE);
+    single_click_fileopen=getApp()->reg().readUnsignedEntry("OPTIONS","single_click_fileopen",FALSE);
+	if (single_click_diropen & single_click_fileopen)
+		list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+
 	// Home and trahscan locations
 	homelocation=getenv("HOME");
     if(homelocation=="")
@@ -170,6 +179,7 @@ FilePanel::FilePanel(FXchar* nm,FXComposite *p, FXuint name_size, FXuint size_si
 	trashlocation=homelocation+PATHSEPSTRING+TRASHPATH;
 
 	updatePathLinker();
+	
 }
 
 
@@ -261,7 +271,7 @@ void FilePanel::updateLocation()
 
 
 // Double Click on File Item
-long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
+long FilePanel::onCmdItemDoubleClicked(FXObject* sender,FXSelector sel, void* ptr)
 {
 	FXString buf, filename, filepath;
 
@@ -332,10 +342,100 @@ long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
 }
 
 
-// Focus when clicked
-long FilePanel::onCmdItemClcked(FXObject* sender,FXSelector sel, void* ptr)
+// Single click on File Item
+long FilePanel::onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr)
 {
-    focus();
+	focus();
+		
+	if (single_click_diropen | single_click_fileopen)
+	{		
+		// Test if a key modifier was pressed
+		FXint x, y;
+		FXuint state;
+		getCursorPosition(x,y,state);
+		
+		// Single click with control or shift
+		if (state&(CONTROLMASK|SHIFTMASK))
+			return 1;
+		
+		// Single click without control or shift
+		else
+		{
+			FXString buf, filename, filepath;
+
+			// Wait cursor
+			getApp()->beginWaitCursor();
+			
+			long item= (long) ptr;
+			if(item > -1)
+			{
+				// File name and path
+				filename=list->getItemFilename(item);
+				filepath=list->getItemPathname(item);
+
+				// If directory, open the directory
+				if(single_click_diropen && list->isItemDirectory(item))
+				{
+					// Does not have access
+					if(!::isReadExecutable(filepath))
+					{
+						MessageBox::error(this,BOX_OK_SU,_("Error"),_(" Permission to: %s denied."), filepath.text());
+						getApp()->endWaitCursor();
+						return 0;
+					}
+					if(filename=="..")
+						list->handle(this,FXSEL(SEL_COMMAND,FileList::ID_DIRECTORY_UP),NULL);
+					else
+						list->setDirectory(filepath);
+					
+					// Change directory in tree list  
+					((XFileExplorer*) mainWindow)->dirpanel->list->setDirectory(filepath,TRUE);
+					current->updatePathLinker();
+					
+					// Update location history			
+					updateLocation();
+				}
+				
+				// If file, use the association if any
+				else if(single_click_fileopen && list->isItemFile(item))
+				{
+					// Update associations dictionary
+					FileDict *assocdict=new FileDict(getApp());			
+					FileAssoc *association=assocdict->findFileBinding(filepath.text());
+
+					if(association)
+						if(association->command.section(',',0).text() != NULL)
+						{
+							buf=association->command.section(',',0)+" \""+filepath+"\"";
+							runcmd(buf);
+						}
+						else if(list->isItemExecutable(item)) //executable
+						{
+							buf="'"+filepath+"'";
+							runcmd(buf);
+					   }    // If regular file return as the selected file
+						else
+							current->handle(this,FXSEL(SEL_COMMAND,ID_OPEN_WITH),NULL);
+					else if(list->isItemExecutable(item))//executable
+					{
+						buf="'"+filepath+"'";
+						runcmd(buf);
+					}    // If regular file return as the selected file
+					else
+						current->handle(this,FXSEL(SEL_COMMAND,ID_OPEN_WITH),NULL);
+				}
+			}
+			getApp()->endWaitCursor();
+		}
+	}
+    return 1;
+}
+
+
+// Focus when clicked
+long FilePanel::onCmdItemFocus(FXObject* sender,FXSelector sel, void* ptr)
+{
+	focus();
     return 1;
 }
 
@@ -1215,7 +1315,7 @@ long FilePanel::onCmdNewDir(FXObject*,FXSelector,void*)
 			FXint ret=::mkdir(dirname.text(),511 & ~mask);
 			if (ret==-1)
 			{
-         		MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno));
+         		MessageBox::error(this,BOX_OK_SU,_("Error"),"%s",strerror(errno));
     			return 0;
 			}
 		}							
@@ -1256,7 +1356,7 @@ long FilePanel::onCmdNewFile(FXObject*,FXSelector,void*)
 			// Create the new file
 			if (!(file=fopen(filename.text(),"w+"))  ||  fclose(file) )
 			{
-         		MessageBox::error(this,BOX_OK,_("Error"),"%s",strerror(errno));
+         		MessageBox::error(this,BOX_OK_SU,_("Error"),"%s",strerror(errno));
     			return 0;
 			}
 			// Change the file permissions according to the current umask
@@ -1717,8 +1817,11 @@ long FilePanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
         new FXMenuRadio(&menu,_("&Type"),current->list,FileList::ID_SORT_BY_TYPE);
         new FXMenuRadio(&menu,_("E&xtension"),current->list,FileList::ID_SORT_BY_EXT);
         new FXMenuRadio(&menu,_("&Date"),current->list,FileList::ID_SORT_BY_TIME);
+        new FXMenuSeparator(&menu);
   		new FXMenuCheck(&menu,_("I&gnore case"),current->list,FileList::ID_SORT_CASE);
-    }
+   		new FXMenuCheck(&menu,_("Dir&ectories first"),current->list,FileList::ID_DIRS_FIRST);
+   		new FXMenuCheck(&menu,_("Re&verse order"),current->list,FileList::ID_SORT_REVERSE);
+   }
     // Non empty selection
 	else
     {
@@ -2886,3 +2989,5 @@ long FilePanel::onUpdAddToArch(FXObject* o,FXSelector,void*)
 		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
     return 1;
 }
+
+
