@@ -1,5 +1,5 @@
-#ifndef HISTDIALOG_H
-#define HISTDIALOG_H
+#ifndef HISTINPUTDIALOG_H
+#define HISTINPUTDIALOG_H
 
 #include "DialogBox.h"
 
