@@ -14,11 +14,11 @@ FXDEFMAP(InputDialog) InputDialogMap[]={
                                            FXMAPFUNC(SEL_KEYPRESS,0,InputDialog::onCmdKeyPress),
                                        };
 // Object implementation
-FXIMPLEMENT(InputDialog,FXDialogBox,InputDialogMap,ARRAYNUMBER(InputDialogMap))
+FXIMPLEMENT(InputDialog,DialogBox,InputDialogMap,ARRAYNUMBER(InputDialogMap))
 
 // Construct a dialog box
-InputDialog::InputDialog(FXWindow *win,FXString& inp,FXString message,FXString title,FXString label,FXIcon *ic):
-        FXDialogBox(win,title,DECOR_TITLE|DECOR_BORDER)
+InputDialog::InputDialog(FXWindow *win,FXString& inp,FXString message,FXString title,FXString label,FXIcon *ic, int option, FXString optiontext):
+        DialogBox(win,title,DECOR_TITLE|DECOR_BORDER)
 {
     // Buttons
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,PACK_UNIFORM_WIDTH|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
@@ -32,6 +32,12 @@ InputDialog::InputDialog(FXWindow *win,FXString& inp,FXString message,FXString t
 	// Separator
     new FXHorizontalSeparator(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);
 
+	// Optional check box
+	checkbutton=new FXHorizontalFrame(this,JUSTIFY_RIGHT|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,0,0);
+    
+	if (option)
+        new FXCheckButton(checkbutton,optiontext,this,ID_TOGGLE_OPTION);
+
     // Vertical frame
 	FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
@@ -80,7 +86,7 @@ InputDialog::InputDialog(FXWindow *win,FXString& inp,FXString message,FXString t
 
 void InputDialog::create()
 {
-    FXDialogBox::create();
+    DialogBox::create();
     input->setFocus();
 }
 
