@@ -1,21 +1,24 @@
-#ifndef IDIALOG_H
-#define IDIALOG_H
+#ifndef INPUTDIALOG_H
+#define INPUTDIALOG_H
+
+#include "DialogBox.h"
 
 class XComApp;
 
-class InputDialog : public FXDialogBox
+class InputDialog : public DialogBox
 {
     FXDECLARE(InputDialog)
 protected:
     FXTextField*       input;
     FXDataTarget*      string_target;
+    FXHorizontalFrame* checkbutton;
 private:
     InputDialog()
     {
         ;
     }
 public:
-    InputDialog(FXWindow*,FXString&,FXString,FXString,FXString label="",FXIcon *ic=NULL);
+    InputDialog(FXWindow*,FXString&,FXString,FXString,FXString label="",FXIcon *ic=NULL, int option=0, FXString=FXString::null);
     virtual void create();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
     FXString getText()
