@@ -24,6 +24,10 @@ FXbool Theme::operator != (const Theme& t)
 // Main window
 extern FXMainWindow *mainWindow;
 
+// Single click navigation
+extern FXbool single_click_diropen;
+extern FXbool single_click_fileopen;
+
 
 // Map
 FXDEFMAP(PreferencesBox) PreferencesMap[]={
@@ -91,15 +95,21 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     // First tab - Options
     new FXTabItem(tabbook,_("&Options"),NULL);
     FXVerticalFrame *options=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
-    FXGroupBox *group=new FXGroupBox(options,_("Options"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+
+	FXGroupBox *group=new FXGroupBox(options,_("Options"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     trashcan=new FXCheckButton(group,_("Use trash can for file deletion (safe delete)")); 
 	trashbypass=new FXCheckButton(group,_("Include a command to bypass the trash can (permanent delete)"),this,ID_TRASH_BYPASS);
+    autosave=new FXCheckButton(group,_("Auto save layout"));
+    diropen=new FXCheckButton(group,_("Single click directory open"));
+    fileopen=new FXCheckButton(group,_("Single click file open"));
+
+	group=new FXGroupBox(options,_("Confirmations"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    ask=new FXCheckButton(group,_("Always ask before file operation"));
 	del=new FXCheckButton(group,_("Confirm delete"));
     overwrite=new FXCheckButton(group,_("Confirm overwrite"));
-    ask=new FXCheckButton(group,_("Always ask before file operation"));
-    autosave=new FXCheckButton(group,_("Auto save layout"));
 	quit=new FXCheckButton(group,_("Confirm quit"));
-    group=new FXGroupBox(options,_("Warnings"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+
+	group=new FXGroupBox(options,_("Warnings"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 #if defined(linux)
     mount=new FXCheckButton (group,_("Warn when mount points are not responding"));
 	show_mount=new FXCheckButton(group, _("Display mount/umount success messages"));
@@ -133,6 +143,10 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	overwrite->setCheck(confirm_overwrite);
     FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
 	ask->setCheck(ask_before_copy);
+    single_click_diropen=getApp()->reg().readUnsignedEntry("OPTIONS","single_click_diropen",FALSE);
+	diropen->setCheck(single_click_diropen);
+    single_click_fileopen=getApp()->reg().readUnsignedEntry("OPTIONS","single_click_fileopen",FALSE);
+	fileopen->setCheck(single_click_fileopen);
 #if defined(linux)
 	FXbool mount_warn=getApp()->reg().readUnsignedEntry("OPTIONS","mount_warn",TRUE);
 	FXbool mount_messages=getApp()->reg().readUnsignedEntry("OPTIONS","mount_messages",TRUE);
@@ -143,7 +157,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     // Second tab - Programs
     new FXTabItem(tabbook,_("&Programs"),NULL);
     FXVerticalFrame *programs=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
-    group=new FXGroupBox(programs,_("Programs"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
+    group=new FXGroupBox(programs,_("Programs"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXMatrix *matrix = new FXMatrix(group,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     new FXLabel(matrix,_("Default text editor:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
@@ -414,7 +428,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		}
 		
 		// Update the registry
-		getApp()->reg().write();
+		//getApp()->reg().write();
 	}
 
     // Text viewer has changed
@@ -458,7 +472,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		}
 		
 		// Update the registry
-		getApp()->reg().write();
+		//getApp()->reg().write();
 	}
 
     // Image viewer has changed
@@ -502,7 +516,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		}
 		
 		// Update the registry
-		getApp()->reg().write();
+		//getApp()->reg().write();
 	}
 
 	// Terminal has changed
@@ -510,18 +524,37 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
         getApp()->reg().writeStringEntry("PROGS","xterm",xterm->getText().text());
 
 	getApp()->reg().writeUnsignedEntry("OPTIONS","auto_save_layout",autosave->getCheck());
-	getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_quit",quit->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","use_trash_can",trashcan->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","use_trash_bypass",trashbypass->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","ask_before_copy",ask->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","single_click_diropen",diropen->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","single_click_fileopen",fileopen->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_delete",del->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_overwrite",overwrite->getCheck());
-    getApp()->reg().writeUnsignedEntry("OPTIONS","ask_before_copy",ask->getCheck());
+	getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_quit",quit->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",root_warning->getCheck());
 #if defined(linux)
     getApp()->reg().writeUnsignedEntry("OPTIONS","mount_warn",mount->getCheck());
 	getApp()->reg().writeUnsignedEntry("OPTIONS","mount_messages",show_mount->getCheck());
 #endif
-    
+	
+	// Update some global options
+	single_click_diropen=diropen->getCheck();
+	single_click_fileopen=fileopen->getCheck();
+	
+	if (single_click_diropen & single_click_fileopen)
+	{
+		((XFileExplorer*) mainWindow)->lpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+		((XFileExplorer*) mainWindow)->rpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+		((XFileExplorer*) mainWindow)->dirpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+	}
+	else
+	{
+		((XFileExplorer*) mainWindow)->lpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+		((XFileExplorer*) mainWindow)->rpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+		((XFileExplorer*) mainWindow)->dirpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+	}
+   
 	// Theme has changed
 	if(currTheme != Themes[0])
     {
@@ -538,6 +571,10 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
         if(BOX_CLICKED_CANCEL!=MessageBox::question(this,BOX_OK_CANCEL,_("Restart"),_("Colors will be changed after restart.\nRestart X File Explorer now?")))
             mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RESTART),NULL);
     }
+	
+	// Update the registry
+	getApp()->reg().write();
+	
     FXDialogBox::onCmdAccept(o,s,p);
     return 1;
 }
