@@ -62,6 +62,8 @@ private:
     FXString    oldnormalfont;
     FXString    oldtextfont;
     FXCheckButton  *autosave;
+    FXCheckButton  *diropen;
+    FXCheckButton  *fileopen;
     FXCheckButton  *quit;
     FXCheckButton  *trashcan;
     FXCheckButton  *trashbypass;
@@ -91,7 +93,7 @@ public:
     };
 
 public:
-    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor highlightcolor=FXRGB(238,2380,238));
+    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor highlightcolor=FXRGB(238,238,238));
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdBrowse(FXObject*,FXSelector,void*);
     long onCmdColor (FXObject*,FXSelector,void*);
