@@ -17,9 +17,9 @@
 #include <mntent.h>
 #endif
 
-#include <fox-1.4/fx.h>
-#include <fox-1.4/fxkeys.h>
-#include <fox-1.4/FXPNGIcon.h>
+#include <fox-1.6/fx.h>
+#include <fox-1.6/fxkeys.h>
+#include <fox-1.6/FXPNGIcon.h>
 
 #include "xfedefs.h"
 #include "icons.h"
@@ -47,7 +47,7 @@ PermFrame::PermFrame(FXComposite* parent,FXObject *target):
         FXVerticalFrame(parent,FRAME_THICK|FRAME_RAISED)
 {
     FXHorizontalFrame *accessframe=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    FXHorizontalFrame *chmodframe=new FXHorizontalFrame(this,PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXHorizontalFrame *chmodframe=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
     
 	// Permissions
 	FXGroupBox *group1=new FXGroupBox(accessframe,_("User"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
@@ -75,9 +75,7 @@ PermFrame::PermFrame(FXComposite* parent,FXObject *target):
 	// User names (sorted in ascending order)
     struct passwd* pwde;
     while( (pwde = getpwent()) )
-    {
         user->appendItem(pwde->pw_name);
-    }
     endpwent();
 	user->setSortFunc(FXList::ascending);
 	user->sortItems();	
@@ -85,30 +83,31 @@ PermFrame::PermFrame(FXComposite* parent,FXObject *target):
 	// Group names (sorted in ascending order)
     struct group* grpe;
     while( (grpe = getgrent()) )
-    {
         grp->appendItem(grpe->gr_name);
-    }
     endgrent();
 	grp->setSortFunc(FXList::ascending);
 	grp->sortItems();	
 
     // Command
 	FXGroupBox *group5=new FXGroupBox(chmodframe,_("Command"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-	radiotarget.connect(cmd);
-	set=new FXRadioButton(group5,_("Set marked"),&radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_SET);
-    clear=new FXRadioButton(group5,_("Clear marked"),&radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_CLEAR);
-    add=new FXRadioButton(group5,_("Add marked"),&radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_ADD);
-    own=new FXCheckButton(group5,_("Owner only"),NULL,0);
-    rec=new FXCheckButton(group5,_("Recursively"),NULL,0);
-    dironly=new FXCheckButton(group5,_("Folders only"),NULL,0);
-    dironly->disable();
-
+    FXMatrix *matrix5 = new FXMatrix(group5,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+	cmd_radiotarget.connect(cmd);
+	set=new FXRadioButton(matrix5,_("Set marked"),&cmd_radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_SET);
+    rec=new FXCheckButton(matrix5,_("Recursively"),NULL,0);
+    clear=new FXRadioButton(matrix5,_("Clear marked"),&cmd_radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_CLEAR);
+	flt_radiotarget.connect(flt);
+    all=new FXRadioButton(matrix5,_("Files and folders"),&flt_radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_ALL);
+    add=new FXRadioButton(matrix5,_("Add marked"),&cmd_radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_ADD);
+	dironly=new FXRadioButton(matrix5,_("Folders only"),&flt_radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_DIRONLY);
+	own=new FXCheckButton(matrix5,_("Owner only"),NULL,0);
+    fileonly=new FXRadioButton(matrix5,_("Files only"),&flt_radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_FILEONLY);
 }
 
 // Map
 FXDEFMAP(PropertiesBox) PropertiesBoxMap[]={
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_SINGLE,PropertiesBox::onCmdAcceptSingle),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_MULT,PropertiesBox::onCmdAcceptMult),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_CANCEL,PropertiesBox::onCmdCancel),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_RUSR,PropertiesBox::onCmdCheck),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WUSR,PropertiesBox::onCmdCheck),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XUSR,PropertiesBox::onCmdCheck),
@@ -122,6 +121,9 @@ FXDEFMAP(PropertiesBox) PropertiesBoxMap[]={
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_SET,PropertiesBox::onCmdCommand),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_CLEAR,PropertiesBox::onCmdCommand),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ADD,PropertiesBox::onCmdCommand),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_DIRONLY,PropertiesBox::onCmdFilter),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_FILEONLY,PropertiesBox::onCmdFilter),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ALL,PropertiesBox::onCmdFilter),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BIG_ICON,PropertiesBox::onCmdBrowseIcon),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_MINI_ICON,PropertiesBox::onCmdBrowseIcon),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_BROWSE_OPEN,PropertiesBox::onCmdBrowse),
@@ -134,16 +136,16 @@ FXDEFMAP(PropertiesBox) PropertiesBoxMap[]={
 FXIMPLEMENT(PropertiesBox,FXDialogBox,PropertiesBoxMap,ARRAYNUMBER(PropertiesBoxMap))
 
 // Construct window for one file
-PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER/*,0,0,350,200*/)
+PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER)
 {
     unsigned long long filesize, dirsize=0;
     FXString mod,changed,accessed;
 	FXString grpid, usrid;	
 	FXLabel *sizelabel=NULL;
-    struct stat info;
+    struct stat info, linfo;
     FXString type, extension, fileassoc;
-    int islink, isdirectory;
-    char filename[MAXPATHLEN+1],linkto[MAXPATHLEN+1];
+    FXbool isLink, isBrokenLink, isDirectory;
+    FXString filename;
     char mnttype[64], used[64], avail[64], size[64];
     char buf[MAXPATHLEN+1];
 	FXString hsize;
@@ -154,7 +156,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
 
     // Contents
-    FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);
+    FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     // Accept
 	if (file!="..")
@@ -172,7 +174,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     // First item is General
     new FXTabItem(tabbook,_("&General"),NULL);
     FXPacker *genpack = new FXPacker(tabbook,FRAME_THICK|FRAME_RAISED);
-    FXGroupBox *generalgroup=new FXGroupBox(genpack,NULL,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXGroupBox *generalgroup=new FXGroupBox(genpack,FXString::null,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXVerticalFrame *generalframe=new FXVerticalFrame(generalgroup,LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     // Second item is Access Permissions
@@ -186,22 +188,22 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     // Third tab - file associations
     FXTabItem *fassoctab = new FXTabItem(tabbook,_("&File Associations"),NULL);
     FXPacker *fassocpack = new FXPacker(tabbook,FRAME_THICK|FRAME_RAISED);
-    FXGroupBox *fassocgroup=new FXGroupBox(fassocpack,NULL,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    FXVerticalFrame *contassoc=new FXVerticalFrame(fassocgroup,LAYOUT_FILL_X|LAYOUT_FILL_Y);//,FRAME_THICK|FRAME_RAISED);
+    FXGroupBox *fassocgroup=new FXGroupBox(fassocpack,FXString::null,FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXVerticalFrame *contassoc=new FXVerticalFrame(fassocgroup,LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXMatrix *matrix = new FXMatrix(contassoc,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     fassoctab->disable();
 
     new FXLabel(matrix,_("Extension:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    ext = new FXTextField(matrix,10,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    ext = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     new FXLabel(matrix,"",NULL,0);
 
     new FXLabel(matrix,_("Description:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    descr = new FXTextField(matrix,10,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    descr = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     new FXLabel(matrix,"",NULL,0);
 
     new FXLabel(matrix,_("Open:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    open = new FXTextField(matrix,10,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXButton(matrix,_(" Select..."),NULL,this,ID_BROWSE_OPEN,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);//,0,0,0,0,0,0);
+    open = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    new FXButton(matrix,_(" Select..."),NULL,this,ID_BROWSE_OPEN,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
 
     int is_ar = FALSE;
 
@@ -209,10 +211,10 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     FXString editlbl=_("Edit:");
 
 	extension=file.rafter('.',1);
-	if (comparecase(extension,"gz") || comparecase(extension,"tgz") ||
-		comparecase(extension,"tar") || comparecase(extension,"bz2") ||
-		comparecase(extension,"tbz2") || comparecase(extension,"zip") ||
-		comparecase(extension,"Z"))
+	if (comparecase(extension,"gz")==0 || comparecase(extension,"tgz")==0 ||
+		comparecase(extension,"tar")==0 || comparecase(extension,"bz2")==0 ||
+		comparecase(extension,"tbz2")==0 || comparecase(extension,"zip")==0 ||
+		comparecase(extension,"Z")==0)
 	{
 		is_ar = TRUE; // archive
 		viewlbl = _("Extract:");
@@ -220,94 +222,93 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 #if defined(linux)
 	else if(extension=="rpm")
 		editlbl = _("Install/Upgrade:");
-#endif
-
+#endif	
     new FXLabel(matrix,viewlbl,NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    view = new FXTextField(matrix,10,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXButton(matrix,_(" Select..."),NULL,this,ID_BROWSE_VIEW,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);//,0,0,0,0,0,0);
+    view = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    new FXButton(matrix,_(" Select..."),NULL,this,ID_BROWSE_VIEW,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
 
     if(!is_ar)
     {
         new FXLabel(matrix,editlbl,NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-        edit = new FXTextField(matrix,10,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-        new FXButton(matrix,_(" Select..."),NULL,this,ID_BROWSE_EDIT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);//,0,0,0,0,0,0);
+        edit = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+        new FXButton(matrix,_(" Select..."),NULL,this,ID_BROWSE_EDIT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
     }
     else
         edit = NULL;
 
     new FXLabel(matrix,_("Big Icon:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    bigic = new FXTextField(matrix,10,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXButton(matrix,_(" Select..."),NULL,this,ID_BIG_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);//,0,0,0,0,0,0);
+    bigic = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    new FXButton(matrix,_(" Select..."),NULL,this,ID_BIG_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
 
     new FXLabel(matrix,_("Mini Icon:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    miniic = new FXTextField(matrix,10,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
-    new FXButton(matrix,_(" Select..."),NULL,this,ID_MINI_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);//,0,0,0,0,0,0);
+    miniic = new FXTextField(matrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    new FXButton(matrix,_(" Select..."),NULL,this,ID_MINI_ICON,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
 
     // Label
     new FXLabel(generalframe,_("Name"),NULL,JUSTIFY_LEFT);
-
-    input = new FXTextField(generalframe,20,NULL,0,LAYOUT_SIDE_TOP|/*LAYOUT_CENTER_Y|*/LAYOUT_CENTER_X|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
+    input = new FXTextField(generalframe,20,NULL,0,LAYOUT_SIDE_TOP|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
 
     // Complete filename (with path)
-	strlcpy(filename,(path+PATHSEPSTRING+file).text(),(path+PATHSEPSTRING+file).length()+1);
+	filename=path+PATHSEPSTRING+file;
 	parentdir=path;
 	
-    // Get file/link info
-    if(lstatout(filename,&info)!=0)
+    // Get file/link stat info
+    if(lstatrep(filename.text(),&linfo)!=0)
         return ;
 
 	// Obtain user name
-	usrid=FXFile::owner(info.st_uid);
+	usrid=FXSystem::userName(linfo.st_uid);
 
 	// Obtain group name
-	grpid=FXFile::group(info.st_gid);
+	grpid=FXSystem::groupName(linfo.st_gid);
     perm->user->setText(usrid);
     perm->grp->setText(grpid);
     oldgrp = grpid;
     oldusr = usrid;
 
-	// If it is a link
-    islink=S_ISLNK(info.st_mode);
-	if(islink)
+	// Test if link or broken link
+	// When valid link, set the file name to the refered file
+    isLink=S_ISLNK(linfo.st_mode);
+	isBrokenLink=FALSE;
+	if(isLink)
 	{
-		// If it is a broken link
-		if (statout(filename,&info)!=0)
-			type="Broken link to ";
-		else
-			type="Link to ";
+		// Broken link
+		if (statrep(filename.text(),&info)!=0)
+			isBrokenLink=TRUE;
 
 		// Get the name of the linked file
-		int nread;
-		nread=readlink(filename,linkto,sizeof(linkto)-1);
-		if(nread>0)
-		{
-			linkto[nread]='\0';
-			strlcpy(filename,linkto,sizeof(linkto));
-		}
+		if (!isBrokenLink)
+			filename=readlink(filename);
+	}
+
+	// Obtain stat info on the file itself
+	if (statrep(filename.text(),&info)!=0)
+	{
+		// Or on the link if broken link
+		if (isBrokenLink)
+			lstatrep(filename.text(),&info);
 	}
-	else
-		type="";
 
     orig_mode=(info.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO));
 
-    // Mod time
-	mod=FXFile::time("%c",info.st_mtime);
+    // Mod time of the file / link
+	mod=FXSystem::time("%c",linfo.st_mtime);
 
-    // Change time
-	changed=FXFile::time("%c",info.st_ctime);
+    // Change time of the file / link
+	changed=FXSystem::time("%c",linfo.st_ctime);
 
-    // Accessed time
-    accessed=FXFile::time("%c",info.st_atime);;
+    // Accessed time of the file / link
+    accessed=FXSystem::time("%c",linfo.st_atime);;
 
-    // Size
-    filesize=(unsigned long long)info.st_size;
+    // Size of the file / link
+    filesize=(unsigned long long)linfo.st_size;
 
     // Is it a directory?
-	isdirectory=S_ISDIR(info.st_mode);
-    if(isdirectory)
+	isDirectory=S_ISDIR(info.st_mode);
+    if(isDirectory)
     {		
 		// Directory path
-		FXString dupath=FXFile::absolute(path,file);
+		FXString dupath=FXPath::absolute(path,file);
 
 #if defined(linux)
 		FILE *mtab=setmntent("/etc/mtab","r");
@@ -322,7 +323,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
                     {
                         ismountpoint=TRUE;
                         snprintf(buf,sizeof(buf)-1,_("Filesystem (%s)"),mnt->mnt_fsname);
-                        type+=buf;
+                        type=buf;
 						strlcpy(mnttype,mnt->mnt_type,strlen(mnt->mnt_type)+1);
                     }
                 }
@@ -333,7 +334,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 		// If it is a mount point
 		if(ismountpoint)
 		{
-			snprintf(buf,sizeof(buf)-1,"df --block-size=1 '%s'",filename);
+			snprintf(buf,sizeof(buf)-1,"df --block-size=1 '%s'",filename.text());
 			p=popen(buf,"r");
 			fgets(buf,sizeof(buf),p);
 			fgets(buf,sizeof(buf),p);
@@ -350,7 +351,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 		// If it is a folder
 		else
 		{
-            type+=_("Folder");
+            type=_("Folder");
     		getApp()->beginWaitCursor();
 			strlcpy(buf,dupath.text(),dupath.length()+1);
 			dirsize=pathsize(buf);
@@ -360,29 +361,29 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     }
 	
     else if(S_ISCHR(info.st_mode))
-        type+="Character Device";
+        type=_("Character Device");
     else if(S_ISBLK(info.st_mode))
-        type+="Block Device";
+        type=_("Block Device");
     else if(S_ISFIFO(info.st_mode))
-        type+="Named Pipe";
+        type=_("Named Pipe");
     else if(S_ISSOCK(info.st_mode))
-        type+="Socket";
+        type=_("Socket");
     
 	// Regular file or link
 	else
     {
 		// Try to use association table	
-		extension=FXFile::name(filename).rafter('.',1);
-        if (extension != "")
+		extension=FXPath::name(filename).rafter('.',1);
+        //if (extension != "")
 			fileassoc=getApp()->reg().readStringEntry("FILETYPES",extension.text(),"");
 
 		// If we have an association
         if(!fileassoc.empty())
         {
             FXString c;
-            type+=fileassoc.section(';',1);
+            type=fileassoc.section(';',1);
             ext->setText(extension);
-            ext->disable();
+            ext->setEditable(FALSE);
             c=fileassoc.section(';',0);
             descr->setText(fileassoc.section(';',1));
             open->setText(c.section(',',0));
@@ -392,21 +393,29 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
             bigic->setText(fileassoc.section(';',2));
             miniic->setText(fileassoc.section(';',3));
 
-            fassoctab->enable();
+            if (!isLink)
+				fassoctab->enable();
         }
         else
         {
             ext->setText(extension);
             ext->disable();
-            if(info.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
-                type+="Application";
+			if(info.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
+                type=_("Executable");
             else
             {
-                type+="Document";
-                fassoctab->enable();
+                type=_("Document");
+				if (!isLink)
+					fassoctab->enable();
             }
         }
     }
+	
+	// Modify file type for links
+	if (isBrokenLink)
+		type=_("Broken link");
+	else if (isLink)
+		type=_("Link to ")+type;
 
 	// Parent directory name not editable
 	if (file=="..")
@@ -427,17 +436,18 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     // Set permissions
 
     perm->ur->setCheck((orig_mode & S_IRUSR) ? TRUE : FALSE);
-    perm->uw->setCheck((info.st_mode & S_IWUSR) ? TRUE : FALSE);
-    perm->ux->setCheck((info.st_mode & S_IXUSR) ? TRUE : FALSE);
+    perm->uw->setCheck((linfo.st_mode & S_IWUSR) ? TRUE : FALSE);
+    perm->ux->setCheck((linfo.st_mode & S_IXUSR) ? TRUE : FALSE);
 
-    perm->gr->setCheck((info.st_mode & S_IRGRP) ? TRUE : FALSE);
-    perm->gw->setCheck((info.st_mode & S_IWGRP) ? TRUE : FALSE);
-    perm->gx->setCheck((info.st_mode & S_IXGRP) ? TRUE : FALSE);
+    perm->gr->setCheck((linfo.st_mode & S_IRGRP) ? TRUE : FALSE);
+    perm->gw->setCheck((linfo.st_mode & S_IWGRP) ? TRUE : FALSE);
+    perm->gx->setCheck((linfo.st_mode & S_IXGRP) ? TRUE : FALSE);
 
-    perm->or_->setCheck((info.st_mode & S_IROTH) ? TRUE : FALSE);
-    perm->ow->setCheck((info.st_mode & S_IWOTH) ? TRUE : FALSE);
-    perm->ox->setCheck((info.st_mode & S_IXOTH) ? TRUE : FALSE);
+    perm->or_->setCheck((linfo.st_mode & S_IROTH) ? TRUE : FALSE);
+    perm->ow->setCheck((linfo.st_mode & S_IWOTH) ? TRUE : FALSE);
+    perm->ox->setCheck((linfo.st_mode & S_IXOTH) ? TRUE : FALSE);
     perm->set->setCheck();
+	perm->all->setCheck();
 
 	FXLabel *mtType=NULL, *mtUsed=NULL, *mtFree=NULL, *fileType=NULL, *fileSize=NULL, *fileChanged=NULL, *fileAccessed=NULL, *fileModified=NULL;
 
@@ -447,38 +457,38 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
   		FXGroupBox *mtgroup=new FXGroupBox(generalframe,_("Mount point"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
   		FXMatrix *mtmatrix=new FXMatrix(mtgroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
   		new FXLabel(mtmatrix,_("Mount type:"),NULL,LAYOUT_LEFT);
-  		fileType=new FXLabel(mtmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		fileType=new FXLabel(mtmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
   		new FXLabel(mtmatrix,_("Used:"),NULL,LAYOUT_LEFT);
-  		mtUsed=new FXLabel(mtmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		mtUsed=new FXLabel(mtmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
   		new FXLabel(mtmatrix,_("Free:"),NULL,LAYOUT_LEFT);
-  		mtFree=new FXLabel(mtmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		mtFree=new FXLabel(mtmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
   		new FXLabel(mtmatrix,_("File system:"),NULL,LAYOUT_LEFT);
-  		mtType=new FXLabel(mtmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		mtType=new FXLabel(mtmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
 	}
 	else
 	{
   		FXGroupBox *attrgroup=new FXGroupBox(generalframe,_("Properties"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
   		FXMatrix *attrmatrix=new FXMatrix(attrgroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
   		new FXLabel(attrmatrix,_("Type:"),NULL,LAYOUT_LEFT);
-  		fileType=new FXLabel(attrmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		fileType=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
   		sizelabel=new FXLabel(attrmatrix,_("Total size:"),NULL,LAYOUT_LEFT);
-  		fileSize=new FXLabel(attrmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		fileSize=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
 
   		FXGroupBox *timegroup=new FXGroupBox(generalframe,_("File Time"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
   		FXMatrix *timematrix=new FXMatrix(timegroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
   		new FXLabel(timematrix,_("Last Modified:"),NULL,LAYOUT_LEFT);
-  		fileModified=new FXLabel(timematrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		fileModified=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
   		new FXLabel(timematrix,_("Last Changed:"),NULL,LAYOUT_LEFT);
-  		fileChanged=new FXLabel(timematrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		fileChanged=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
   		new FXLabel(timematrix,_("Last Accessed:"),NULL,LAYOUT_LEFT);
-  		fileAccessed=new FXLabel(timematrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+  		fileAccessed=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
 	}
 
     // File or mount type
 	fileType->setText(type.text());
 
 	// If directory
-	if (isdirectory)
+	if (isDirectory)
 	{
 		// if mount point
 		if(ismountpoint)
@@ -514,27 +524,28 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     }
     mode = orig_mode;
     perm->cmd=PropertiesBox::ID_SET;
+    perm->flt=PropertiesBox::ID_ALL;
     files = &file;
     source = file;
     num = 1;	
 }
 
 // Construct window for multiple files
-PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path): FXDialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER/*,0,0,350,200*/)
+PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path): FXDialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER)
 {
 	unsigned long long filesize, dirsize, totalsize=0;
 	struct stat info;
 	FXString grpid, usrid;
     FXString type, extension, fileassoc;
     char buf[MAXPATHLEN+1];
-	int i, isdirectory, nbdirs=0, nbfiles=0, dotdot=0;
+	int i, isDirectory, nbdirs=0, nbfiles=0, dotdot=0;
 	FXbool firstfile=TRUE;
 
     // Buttons
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
 
     // Contents
-    FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);
+    FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     // Accept
     FXButton *ok = new FXButton(buttons,_("&Accept"),NULL,this,PropertiesBox::ID_ACCEPT_MULT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
@@ -552,11 +563,11 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 	FXGroupBox *attrgroup=new FXGroupBox(generalframe,_("Properties"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	FXMatrix *attrmatrix=new FXMatrix(attrgroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 	new FXLabel(attrmatrix,_("Selection:"),NULL,LAYOUT_LEFT);
-	FXLabel *filesSelected=new FXLabel(attrmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+	FXLabel *filesSelected=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
 	new FXLabel(attrmatrix,_("Type:"),NULL,LAYOUT_LEFT);
-	FXLabel *filesType=new FXLabel(attrmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+	FXLabel *filesType=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
 	new FXLabel(attrmatrix,_("Total size:"),NULL,LAYOUT_LEFT);
-	FXLabel *filesSize=new FXLabel(attrmatrix,NULL,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
+	FXLabel *filesSize=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
 
     // Second item is Access Permissions
     new FXTabItem(tabbook,_("&Permissions"),NULL);
@@ -564,14 +575,14 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 
     // Get file/link info of the second file of the list (the first should be ".."
 	// This is used as a guess for the username, group and permissions of the whole list
-    if(lstatout(file[1].text(),&info)!=0)
+    if(lstatrep(file[1].text(),&info)!=0)
         return ;
 
 	// Obtain user name
-	usrid=FXFile::owner(info.st_uid);
+	usrid=FXSystem::userName(info.st_uid);
 
 	// Obtain group name
-	grpid=FXFile::group(info.st_gid);
+	grpid=FXSystem::groupName(info.st_gid);
 
     orig_mode=(info.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO));
 
@@ -587,12 +598,14 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
     perm->ow->setCheck((info.st_mode & S_IWOTH) ? TRUE : FALSE);
     perm->ox->setCheck((info.st_mode & S_IXOTH) ? TRUE : FALSE);
     perm->add->setCheck();
+	perm->all->setCheck();
 
     perm->user->setText(usrid);
     perm->grp->setText(grpid);
 
     mode = orig_mode;
     perm->cmd = PropertiesBox::ID_SET;
+	perm->flt = PropertiesBox::ID_ALL;
     files = file;
     source = "";
     num = n;
@@ -603,7 +616,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 	// Total size and files type
 	for(i=0;i<num;i++)
 	{
-		if(lstatout(files[i].text(),&info)!=0)
+		if(lstatrep(files[i].text(),&info)!=0)
 			continue ;
 
 		// Special case of the ".." directory
@@ -614,11 +627,11 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 		}
 
 		// Is it a directory?
-		isdirectory=S_ISDIR(info.st_mode);
-		if(isdirectory)
+		isDirectory=S_ISDIR(info.st_mode);
+		if(isDirectory)
 		{
 			// Recursive size
-			FXString dupath=FXFile::absolute(path,files[i]);
+			FXString dupath=FXPath::absolute(path,files[i]);
 			strlcpy(buf,dupath.text(),dupath.length()+1);
 			dirsize=pathsize(buf);
 			totalsize+=dirsize;
@@ -632,7 +645,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 			nbfiles++;
 
 			// Try to use association table	
-			extension=FXFile::name(files[i]).rafter('.',1);
+			extension=FXPath::name(files[i]).rafter('.',1);
        		if (extension != "")
 				fileassoc=getApp()->reg().readStringEntry("FILETYPES",extension.text(),"");
 
@@ -679,7 +692,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 	filesSize->setText(size);
 	
 	// Number of selected files
-	snprintf(buf,sizeof(buf)-1,_("%d items in %d folder(s) and %d file(s)"),num,nbdirs+dotdot,nbfiles);
+	snprintf(buf,sizeof(buf)-1,_("%d items including %d folder(s) and %d file(s)"),num,nbdirs+dotdot,nbfiles);
 	filesSelected->setText(buf);
 
 	// Display type of selected files
@@ -717,7 +730,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
         {
             struct stat info;
             mode_t m;
-            if(lstatout(files[i].text(),&info)!=0)
+            if(lstatrep(files[i].text(),&info)!=0)
                 continue ;
 
             switch(perm->cmd)
@@ -738,13 +751,13 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
             
 			if (files[i]!=".." && !perm->own->getCheck())
 			{
-				rc=f->chmod(strdup(files[i].text()),file,m,perm->rec->getCheck(),perm->dironly->getCheck());
+				rc=f->chmod(strdup(files[i].text()),file,m,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
 				
 				// If action is cancelled in progress dialog
 				if (f->isCancelled)
 				{
 					f->hide();
-					MessageBox::error(this,MBOX_OK,_("Error"),_("Change file(s) permissions cancelled!"));
+					MessageBox::error(this,BOX_OK,_("Error"),_("Change file(s) permissions cancelled!"));
 					delete f;
 					getApp()->endWaitCursor();
 					return 1;
@@ -753,7 +766,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 				// Handle chmod errors
 				if(rc)
 				{
-            		MessageBox::error(this,MBOX_OK,_("Error"),_("Chmod failed in %s : %s"),file,strerror(errno));
+            		MessageBox::error(this,BOX_OK,_("Error"),_("Chmod failed in %s : %s"),file,strerror(errno));
 					break;
 				}
 			}
@@ -775,7 +788,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
         for(i=0;i<num;i++)
         {
             struct stat info;
-            if(lstatout(files[i].text(),&info)!=0)
+            if(lstatrep(files[i].text(),&info)!=0)
                 continue ;
 
             uid_t uid = 32768;
@@ -793,13 +806,13 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
             endgrent();
 
 			if (files[i]!="..")
-            	rc |= f->chown(strdup(files[i].text()),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck());
+            	rc |= f->chown(strdup(files[i].text()),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
 
 			// If action is cancelled in progress dialog
 			if (f->isCancelled)
 			{
 				f->hide();
-				MessageBox::error(this,MBOX_OK,_("Error"),_("Change owner cancelled!"));
+				MessageBox::error(this,BOX_OK,_("Error"),_("Change owner cancelled!"));
 				delete f;
 				getApp()->endWaitCursor();
 				return 1;
@@ -808,15 +821,21 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 			// Handle chmod errors
             if(rc)
             {
-                MessageBox::error(this,MBOX_OK,_("Error"),_("Chown failed in %s : %s"),file,strerror(errno));
+                MessageBox::error(this,BOX_OK,_("Error"),_("Chown failed in %s : %s"),file,strerror(errno));
                 break;
             }
         }
 		delete f;
 		getApp()->endWaitCursor();
     }
+
+	// Redraw the file lists
+	((XFileExplorer*) mainWindow)->rpanel->list->recalc();
+	((XFileExplorer*) mainWindow)->lpanel->list->recalc();
+
 	// FilePanel and DirPanel refresh
 	//mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_REFRESH),NULL);
+
     return 1;
 }
 
@@ -873,20 +892,20 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 	{
 		// Source is not writable
 		if (!::isWritable(source))
-        	MessageBox::error(this,MBOX_OK,_("Error"),_("Can't write to %s : Permission denied"),source.text());
+        	MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't write to %s : Permission denied"),source.text());
 		
 		// Target parent directory doesn't exist or is not writable
-		FXString targetparentdir=FXFile::directory(target);
+		FXString targetparentdir=FXPath::directory(target);
 		if (targetparentdir=="")
 			targetparentdir=parentdir;
 		if (!::exists(targetparentdir))
         {
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Folder %s doesn't exist"),targetparentdir.text());
+			MessageBox::error(this,BOX_OK,_("Error"),_("Folder %s doesn't exist"),targetparentdir.text());
         	return 0;
 		}
 		if (!::isWritable(targetparentdir))
 		{
-         	MessageBox::error(this,MBOX_OK,_("Error"),_("Can't write to %s : Permission denied"),targetparentdir.text());
+         	MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't write to %s : Permission denied"),targetparentdir.text());
         	return 0;
 		}
 
@@ -915,7 +934,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
         mode_t m;
 		
 		FXString filepath=parentdir+"/"+input->getText().text();
-        if(lstatout(filepath.text(),&info)!=0)
+        if(lstatrep(filepath.text(),&info)!=0)
             return 1;
 			
         f = new File(this,_("File permissions"),CHMOD);
@@ -940,13 +959,13 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		getApp()->beginWaitCursor();
 
 		// Perform chmod on the selected file or directory
-		rc=f->chmod(strdup(filepath.text()),file,m,perm->rec->getCheck(),perm->dironly->getCheck());
+		rc=f->chmod(strdup(filepath.text()),file,m,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
 
 		// If action is cancelled in progress dialog
 		if (f->isCancelled)
 		{
 			f->hide();
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Change file permissions cancelled!"));
+			MessageBox::error(this,BOX_OK,_("Error"),_("Change file permissions cancelled!"));
 			delete f;
 			getApp()->endWaitCursor();
 			return 1;
@@ -956,7 +975,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
         
 		// Handle chmod errors
 		if(rc)
-            MessageBox::error(this,MBOX_OK,_("Error"),_("Chmod in %s failed: %s"), file, strerror(errno));
+            MessageBox::error(this,BOX_OK,_("Error"),_("Chmod in %s failed: %s"), file, strerror(errno));
     }
 
     // chown if needed
@@ -985,13 +1004,13 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 
         // Perform chown on the selected file or directory
 		FXString filepath=parentdir+"/"+input->getText().text();
-		rc = f->chown(strdup(filepath.text()),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck());
+		rc = f->chown(strdup(filepath.text()),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
 
 		// If action is cancelled in progress dialog
 		if (f->isCancelled)
 		{
 			f->hide();
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Change owner cancelled!"));
+			MessageBox::error(this,BOX_OK,_("Error"),_("Change owner cancelled!"));
 			delete f;
 			getApp()->endWaitCursor();
 			return 1;
@@ -1001,20 +1020,42 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		
 		// Handle chown errors
         if(rc)
-            MessageBox::error(this,MBOX_OK,_("Error"),_("Chown failed in %s: %s"),file,strerror(errno));
+            MessageBox::error(this,BOX_OK,_("Error"),_("Chown failed in %s: %s"),file,strerror(errno));
     }
 	
+	// Redraw the file lists
+	((XFileExplorer*) mainWindow)->rpanel->list->recalc();
+	((XFileExplorer*) mainWindow)->lpanel->list->recalc();
+
 	// FilePanel and DirPanel refresh
 	//mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_REFRESH),NULL);
+
     return 1;
 }
 
-long PropertiesBox::onCmdCommand(FXObject* o,FXSelector s,void* p)
+long PropertiesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
+{
+    FXDialogBox::onCmdCancel(o,s,p);
+	
+	// Redraw the file lists
+	((XFileExplorer*) mainWindow)->rpanel->list->recalc();
+	((XFileExplorer*) mainWindow)->lpanel->list->recalc();
+
+	return 1;
+}
+
+	
+	long PropertiesBox::onCmdCommand(FXObject* o,FXSelector s,void* p)
 {
     perm->cmd = FXSELID(s);
     return 1;
 }
 
+long PropertiesBox::onCmdFilter(FXObject* o,FXSelector s,void* p)
+{
+    perm->flt = FXSELID(s);
+    return 1;
+}
 
 long PropertiesBox::onCmdCheck(FXObject* o,FXSelector s,void* p)
 {
@@ -1061,11 +1102,12 @@ long PropertiesBox::onCmdCheck(FXObject* o,FXSelector s,void* p)
 
 long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 {
-    FileDialog browseProgram(this,_("Select Program"));
+    FileDialog browseProgram(this,_("Select Program"),0,0,0,600,400);
     const FXchar *patterns[]=
         {
             _("All files"),     "*",NULL
         };
+	browseProgram.setFilename(ROOTDIR);
 	browseProgram.setPatternList(patterns);
     if(browseProgram.execute())
     {
@@ -1073,14 +1115,14 @@ long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
         switch(FXSELID(s))
         {
         	case ID_BROWSE_OPEN:
-            	open->setText(FXFile::name(path).text());
+            	open->setText(FXPath::name(path).text());
             	break;
         	case ID_BROWSE_VIEW:
-            	view->setText(FXFile::name(path).text());
+            	view->setText(FXPath::name(path).text());
             	break;
         	case ID_BROWSE_EDIT:
             	if(edit)
-                	edit->setText(FXFile::name(path).text());
+                	edit->setText(FXPath::name(path).text());
             	break;
         }
     }
@@ -1096,14 +1138,14 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
     else
         icon= miniic->getText();
 
-	FXString iconpath=getApp()->reg().readStringEntry("SETTINGS","iconpath","/usr/lib/foxicons");
+	FXString iconpath=getApp()->reg().readStringEntry("SETTINGS","iconpath",DEFAULTICONPATH);
     const FXchar *patterns[]=
         {
             _("PNG Images"),     "*.png",
 			_("GIF Images"),     "*.gif",
             _("BMP Images"),     "*.bmp",NULL
         };
-    FileDialog browseIcon(this,_("Select Icon"));
+    FileDialog browseIcon(this,_("Select Icon"),0,0,0,600,400);
     browseIcon.setFilename(iconpath+PATHSEPSTRING+icon);
     browseIcon.setPatternList(patterns);
     if(browseIcon.execute())
@@ -1122,9 +1164,17 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
 long PropertiesBox::onUpdPerm(FXObject* o,FXSelector s,void* p)
 {
     if(perm->rec->getCheck())
+	{
         perm->dironly->enable();
+        perm->fileonly->enable();
+		perm->all->enable();
+	}
     else
+	{
+		perm->all->disable();
         perm->dironly->disable();
+        perm->fileonly->disable();
+	}
 
     if(perm->own->getCheck())
 	{
