@@ -19,15 +19,19 @@ private:
     FXCheckButton*	or_;
     FXCheckButton*	ow;
     FXCheckButton*	ox;
-	FXDataTarget	radiotarget;
+	FXDataTarget	cmd_radiotarget;
+	FXDataTarget	flt_radiotarget;
 	FXRadioButton*	set;
 	FXRadioButton*	clear;
+	FXRadioButton*	dironly;
+	FXRadioButton*	fileonly;
+	FXRadioButton*	all;
 	FXRadioButton*	add;
-	FXint			cmd;		  
+	FXint			cmd;
+	FXint			flt;
     FXCheckButton*	rec;
     FXCheckButton*	own;
-    FXCheckButton*	dironly;
-    FXComboBox*		user;
+	FXComboBox*		user;
     FXComboBox*		userbis;
     FXComboBox*		grp;
 public:
@@ -41,7 +45,7 @@ class PropertiesBox : public FXDialogBox
 private:
     PropertiesBox()
     {}
-    FXLabel		*fileSize;
+	FXLabel		*fileSize;
     FXString 	*files;
     FXString 	source;
 	FXString	parentdir;
@@ -75,9 +79,13 @@ public:
     enum{
         ID_ACCEPT_SINGLE=FXDialogBox::ID_LAST,
         ID_ACCEPT_MULT,
+		ID_CANCEL,
         ID_SET,
         ID_CLEAR,
         ID_ADD,
+		ID_DIRONLY,
+		ID_FILEONLY,
+		ID_ALL,
         ID_BIG_ICON,
         ID_MINI_ICON,
         ID_BROWSE_OPEN,
@@ -101,8 +109,10 @@ public:
     PropertiesBox(FXWindow *win,FXString *files,int num,FXString path);
     long onCmdAcceptSingle(FXObject*,FXSelector,void*);
     long onCmdAcceptMult(FXObject*,FXSelector,void*);
+    long onCmdCancel(FXObject*,FXSelector,void*);
     long onCmdCheck(FXObject*,FXSelector,void*);
     long onCmdCommand(FXObject*,FXSelector,void*);
+    long onCmdFilter(FXObject*,FXSelector,void*);
     long onCmdBrowseIcon(FXObject*,FXSelector,void*);
     long onCmdBrowse(FXObject*,FXSelector,void*);
 	long onUpdPerm(FXObject*,FXSelector,void*);
