@@ -20,10 +20,11 @@ public:
 public:
     TextWindow(FXWindow *owner, const FXString& name, FXint nblines, FXint nbcols);
     virtual ~TextWindow();
-	void TextWindow::setText(const FXchar*);
-	void TextWindow::appendText(const FXchar* str);
-	void TextWindow::scrollToLastLine(void);
-	FXint TextWindow::getLength(void);
+	void setText(const FXchar*);
+	void appendText(const FXchar* str);
+	void scrollToLastLine(void);
+	void setFont(FXFont* font);
+	FXint getLength(void);
 };
 
 #endif
