@@ -48,6 +48,8 @@ char OpenHistory[OPEN_WITH_HIST_SIZE][100];
 int OpenNum;
 FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
+FXbool single_click_diropen=FALSE;
+FXbool single_click_fileopen=FALSE;
 
 
 
@@ -209,82 +211,159 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
 	FXString sort_func=getApp()->reg().readStringEntry("LEFT PANEL","sort_func","ascendingCase");
     if (sort_func=="ascendingCase")
 		lpanel->list->setSortFunc(lpanel->list->ascendingCase);        
+    if (sort_func=="ascendingCaseMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingCaseMix);        
     else if (sort_func=="descendingCase")
 		lpanel->list->setSortFunc(lpanel->list->descendingCase);        
+    else if (sort_func=="descendingCaseMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingCaseMix);        
     else if (sort_func=="ascending")
 		lpanel->list->setSortFunc(lpanel->list->ascending);        
+	else if (sort_func=="ascendingMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingMix);        
     else if (sort_func=="descending")
 		lpanel->list->setSortFunc(lpanel->list->descending);        
+    else if (sort_func=="descendingMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingMix);        
 	else if (sort_func=="ascendingSize")
 		lpanel->list->setSortFunc(lpanel->list->ascendingSize);        
+	else if (sort_func=="ascendingSizeMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingSizeMix);        
 	else if (sort_func=="descendingSize")
 		lpanel->list->setSortFunc(lpanel->list->descendingSize);        
+	else if (sort_func=="descendingSizeMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingSizeMix);        
 	else if (sort_func=="ascendingType")
 		lpanel->list->setSortFunc(lpanel->list->ascendingType);        
+	else if (sort_func=="ascendingTypeMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingTypeMix);        
 	else if (sort_func=="descendingType")
 		lpanel->list->setSortFunc(lpanel->list->descendingType);        
+	else if (sort_func=="descendingTypeMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingTypeMix);        
 	else if (sort_func=="ascendingExt")
 		lpanel->list->setSortFunc(lpanel->list->ascendingExt);        
+	else if (sort_func=="ascendingExtMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingExtMix);        
 	else if (sort_func=="descendingExt")
 		lpanel->list->setSortFunc(lpanel->list->descendingExt);        
+	else if (sort_func=="descendingExtMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingExtMix);        
 	else if (sort_func=="ascendingTime")
 		lpanel->list->setSortFunc(lpanel->list->ascendingTime);        
+	else if (sort_func=="ascendingTimeMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingTimeMix);        
 	else if (sort_func=="descendingTime")
 		lpanel->list->setSortFunc(lpanel->list->descendingTime);        
+	else if (sort_func=="descendingTimeMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingTimeMix);        
 	else if (sort_func=="ascendingUser")
 		lpanel->list->setSortFunc(lpanel->list->ascendingUser);        
+	else if (sort_func=="ascendingUserMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingUserMix);        
 	else if (sort_func=="descendingUser")
 		lpanel->list->setSortFunc(lpanel->list->descendingUser);         
+	else if (sort_func=="descendingUserMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingUserMix);         
 	else if (sort_func=="ascendingGroup")
 		lpanel->list->setSortFunc(lpanel->list->ascendingGroup);        
+	else if (sort_func=="ascendingGroupMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingGroupMix);        
 	else if (sort_func=="descendingGroup")
 		lpanel->list->setSortFunc(lpanel->list->descendingGroup);        
+	else if (sort_func=="descendingGroupMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingGroupMix);        
 	else if (sort_func=="ascendingPerm")
 		lpanel->list->setSortFunc(lpanel->list->ascendingPerm);        
+	else if (sort_func=="ascendingPermMix")
+		lpanel->list->setSortFunc(lpanel->list->ascendingPermMix);        
 	else if (sort_func=="descendingPerm")
 		lpanel->list->setSortFunc(lpanel->list->descendingPerm);        
+	else if (sort_func=="descendingPermMix")
+		lpanel->list->setSortFunc(lpanel->list->descendingPermMix);        
 	FXuint ignore_case=getApp()->reg().readUnsignedEntry("LEFT PANEL","ignore_case",1);
 	lpanel->list->setIgnoreCase(ignore_case);        
+	FXuint dirs_first=getApp()->reg().readUnsignedEntry("LEFT PANEL","dirs_first",1);
+	lpanel->list->setDirsFirst(dirs_first);        
 
 	// Read and set sort function for right panel
 	sort_func=getApp()->reg().readStringEntry("RIGHT PANEL","sort_func","ascendingCase");
     if (sort_func=="ascendingCase")
 		rpanel->list->setSortFunc(rpanel->list->ascendingCase);        
+    if (sort_func=="ascendingCaseMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingCaseMix);        
     else if (sort_func=="descendingCase")
 		rpanel->list->setSortFunc(rpanel->list->descendingCase);        
+    else if (sort_func=="descendingCaseMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingCaseMix);        
     else if (sort_func=="ascending")
 		rpanel->list->setSortFunc(rpanel->list->ascending);        
+	else if (sort_func=="ascendingMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingMix);        
     else if (sort_func=="descending")
 		rpanel->list->setSortFunc(rpanel->list->descending);        
+    else if (sort_func=="descendingMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingMix);        
 	else if (sort_func=="ascendingSize")
 		rpanel->list->setSortFunc(rpanel->list->ascendingSize);        
+	else if (sort_func=="ascendingSizeMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingSizeMix);        
 	else if (sort_func=="descendingSize")
 		rpanel->list->setSortFunc(rpanel->list->descendingSize);        
+	else if (sort_func=="descendingSizeMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingSizeMix);        
 	else if (sort_func=="ascendingType")
 		rpanel->list->setSortFunc(rpanel->list->ascendingType);        
+	else if (sort_func=="ascendingTypeMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingTypeMix);        
 	else if (sort_func=="descendingType")
 		rpanel->list->setSortFunc(rpanel->list->descendingType);        
+	else if (sort_func=="descendingTypeMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingTypeMix);        
 	else if (sort_func=="ascendingExt")
 		rpanel->list->setSortFunc(rpanel->list->ascendingExt);        
+	else if (sort_func=="ascendingExtMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingExtMix);        
 	else if (sort_func=="descendingExt")
 		rpanel->list->setSortFunc(rpanel->list->descendingExt);        
+	else if (sort_func=="descendingExtMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingExtMix);        
 	else if (sort_func=="ascendingTime")
 		rpanel->list->setSortFunc(rpanel->list->ascendingTime);        
+	else if (sort_func=="ascendingTimeMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingTimeMix);        
 	else if (sort_func=="descendingTime")
 		rpanel->list->setSortFunc(rpanel->list->descendingTime);        
+	else if (sort_func=="descendingTimeMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingTimeMix);        
 	else if (sort_func=="ascendingUser")
 		rpanel->list->setSortFunc(rpanel->list->ascendingUser);        
+	else if (sort_func=="ascendingUserMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingUserMix);        
 	else if (sort_func=="descendingUser")
 		rpanel->list->setSortFunc(rpanel->list->descendingUser);         
+	else if (sort_func=="descendingUserMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingUserMix);         
 	else if (sort_func=="ascendingGroup")
 		rpanel->list->setSortFunc(rpanel->list->ascendingGroup);        
+	else if (sort_func=="ascendingGroupMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingGroupMix);        
 	else if (sort_func=="descendingGroup")
-		rpanel->list->setSortFunc(rpanel->list->descendingPerm);        
+		rpanel->list->setSortFunc(rpanel->list->descendingGroup);        
+	else if (sort_func=="descendingGroupMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingGroupMix);        
 	else if (sort_func=="ascendingPerm")
 		rpanel->list->setSortFunc(rpanel->list->ascendingPerm);        
+	else if (sort_func=="ascendingPermMix")
+		rpanel->list->setSortFunc(rpanel->list->ascendingPermMix);        
 	else if (sort_func=="descendingPerm")
+		rpanel->list->setSortFunc(rpanel->list->descendingPerm);        
+	else if (sort_func=="descendingPermMix")
+		rpanel->list->setSortFunc(rpanel->list->descendingPermMix);        
 	ignore_case=getApp()->reg().readUnsignedEntry("RIGHT PANEL","ignore_case",1);
 	rpanel->list->setIgnoreCase(ignore_case);        
+	dirs_first=getApp()->reg().readUnsignedEntry("RIGHT PANEL","dirs_first",1);
+	rpanel->list->setDirsFirst(dirs_first);        
 
     FXButton *btn=NULL;
     FXToggleButton *tgbtn=NULL;
@@ -510,7 +589,9 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuRadio(lpanelmenu,_("T&ype"),lpanel->list,FileList::ID_SORT_BY_TYPE);
     new FXMenuRadio(lpanelmenu,_("E&xtension"),lpanel->list,FileList::ID_SORT_BY_EXT);
     new FXMenuRadio(lpanelmenu,_("Ti&me"),lpanel->list,FileList::ID_SORT_BY_TIME);
+    new FXMenuSeparator(lpanelmenu);
   	new FXMenuCheck(lpanelmenu,_("I&gnore case"),lpanel->list,FileList::ID_SORT_CASE);
+  	new FXMenuCheck(lpanelmenu,_("&Directories first"),lpanel->list,FileList::ID_DIRS_FIRST);
     lpanelmenutitle=new FXMenuTitle(menubar,_("&Left panel"),NULL,lpanelmenu);
 
     // Right View Menu Pane
@@ -531,7 +612,9 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuRadio(rpanelmenu,_("T&ype"),rpanel->list,FileList::ID_SORT_BY_TYPE);
     new FXMenuRadio(rpanelmenu,_("E&xtension"),rpanel->list,FileList::ID_SORT_BY_EXT);
     new FXMenuRadio(rpanelmenu,_("Ti&me"),rpanel->list,FileList::ID_SORT_BY_TIME);
+    new FXMenuSeparator(rpanelmenu);
   	new FXMenuCheck(rpanelmenu,_("I&gnore case"),rpanel->list,FileList::ID_SORT_CASE);
+  	new FXMenuCheck(rpanelmenu,_("&Directories first"),rpanel->list,FileList::ID_DIRS_FIRST);
     rpanelmenutitle=new FXMenuTitle(menubar,_("&Right panel"),NULL,rpanelmenu);
 
 
@@ -595,44 +678,81 @@ void XFileExplorer::saveConfig()
 		FXString sort_func;
 		if (lpanel->list->getSortFunc()==lpanel->list->ascendingCase)
 			sort_func="ascendingCase";
+		if (lpanel->list->getSortFunc()==lpanel->list->ascendingCaseMix)
+			sort_func="ascendingCaseMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingCase)
 			sort_func="descendingCase";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingCaseMix)
+			sort_func="descendingCaseMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascending)
 			sort_func="ascending";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingMix)
+			sort_func="ascendingMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descending)
 			sort_func="descending";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingMix)
+			sort_func="descendingMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingSize)
 			sort_func="ascendingSize";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingSizeMix)
+			sort_func="ascendingSizeMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingSize)
 			sort_func="descendingSize";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingSizeMix)
+			sort_func="descendingSizeMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingType)
 			sort_func="ascendingType";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingTypeMix)
+			sort_func="ascendingTypeMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingType)
 			sort_func="descendingType";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingTypeMix)
+			sort_func="descendingTypeMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingExt)
 			sort_func="ascendingExt";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingExtMix)
+			sort_func="ascendingExtMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingExt)
 			sort_func="descendingExt";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingExtMix)
+			sort_func="descendingExtMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingTime)
 			sort_func="ascendingTime";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingTimeMix)
+			sort_func="ascendingTimeMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingTime)
 			sort_func="descendingTime";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingTimeMix)
+			sort_func="descendingTimeMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingUser)
 			sort_func="ascendingUser";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingUserMix)
+			sort_func="ascendingUserMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingUser)
 			sort_func="descendingUser";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingUserMix)
+			sort_func="descendingUserMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingGroup)
 			sort_func="ascendingGroup";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingGroupMix)
+			sort_func="ascendingGroupMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingGroup)
 			sort_func="descendingGroup";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingGroupMix)
+			sort_func="descendingGroupMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingPerm)
 			sort_func="ascendingPerm";
+		else if (lpanel->list->getSortFunc()==lpanel->list->ascendingPermMix)
+			sort_func="ascendingPermMix";
 		else if (lpanel->list->getSortFunc()==lpanel->list->descendingPerm)
 			sort_func="descendingPerm";
+		else if (lpanel->list->getSortFunc()==lpanel->list->descendingPermMix)
+			sort_func="descendingPermMix";
 		else
 			sort_func="ascendingCase";
 		getApp()->reg().writeStringEntry("LEFT PANEL","sort_func",sort_func.text());
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","ignore_case",lpanel->list->getIgnoreCase());
+        getApp()->reg().writeUnsignedEntry("LEFT PANEL","dirs_first",lpanel->list->getDirsFirst());
 
 		getApp()->reg().writeUnsignedEntry("RIGHT PANEL","name_size",rpanel->list->getHeaderSize(0));
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","size_size",rpanel->list->getHeaderSize(1));
@@ -651,44 +771,81 @@ void XFileExplorer::saveConfig()
 		// Get and write sort function for right panel
 		if (rpanel->list->getSortFunc()==rpanel->list->ascendingCase)
 			sort_func="ascendingCase";
+		if (rpanel->list->getSortFunc()==rpanel->list->ascendingCaseMix)
+			sort_func="ascendingCaseMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingCase)
 			sort_func="descendingCase";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingCaseMix)
+			sort_func="descendingCaseMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascending)
 			sort_func="ascending";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingMix)
+			sort_func="ascendingMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descending)
 			sort_func="descending";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingMix)
+			sort_func="descendingMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingSize)
 			sort_func="ascendingSize";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingSizeMix)
+			sort_func="ascendingSizeMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingSize)
 			sort_func="descendingSize";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingSizeMix)
+			sort_func="descendingSizeMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingType)
 			sort_func="ascendingType";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingTypeMix)
+			sort_func="ascendingTypeMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingType)
 			sort_func="descendingType";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingTypeMix)
+			sort_func="descendingTypeMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingExt)
 			sort_func="ascendingExt";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingExtMix)
+			sort_func="ascendingExtMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingExt)
 			sort_func="descendingExt";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingExtMix)
+			sort_func="descendingExtMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingTime)
 			sort_func="ascendingTime";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingTimeMix)
+			sort_func="ascendingTimeMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingTime)
 			sort_func="descendingTime";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingTimeMix)
+			sort_func="descendingTimeMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingUser)
 			sort_func="ascendingUser";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingUserMix)
+			sort_func="ascendingUserMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingUser)
 			sort_func="descendingUser";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingUserMix)
+			sort_func="descendingUserMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingGroup)
 			sort_func="ascendingGroup";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingGroupMix)
+			sort_func="ascendingGroupMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingGroup)
 			sort_func="descendingGroup";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingGroupMix)
+			sort_func="descendingGroupMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingPerm)
 			sort_func="ascendingPerm";
+		else if (rpanel->list->getSortFunc()==rpanel->list->ascendingPermMix)
+			sort_func="ascendingPermMix";
 		else if (rpanel->list->getSortFunc()==rpanel->list->descendingPerm)
 			sort_func="descendingPerm";
+		else if (rpanel->list->getSortFunc()==rpanel->list->descendingPermMix)
+			sort_func="descendingPermMix";
 		else
 			sort_func="ascendingCase";
 		getApp()->reg().writeStringEntry("RIGHT PANEL","sort_func",sort_func.text());
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","ignore_case",rpanel->list->getIgnoreCase());
+        getApp()->reg().writeUnsignedEntry("RIGHT PANEL","dirs_first",rpanel->list->getDirsFirst());
 
         // Global options
 		getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
@@ -701,6 +858,8 @@ void XFileExplorer::saveConfig()
         getApp()->reg().writeUnsignedEntry("OPTIONS","panel_view",(FXuint)panel_view);
         getApp()->reg().writeUnsignedEntry("OPTIONS","tree_width",(FXuint)dirpanel->getWidth());
         getApp()->reg().writeUnsignedEntry("OPTIONS","tree_hidden_dir",dirpanel->list->showHiddenFiles());
+        getApp()->reg().writeUnsignedEntry("OPTIONS","single_click_diropen",single_click_diropen);
+        getApp()->reg().writeUnsignedEntry("OPTIONS","single_click_fileopen",single_click_fileopen);
 
 
         FXString history="";
@@ -2085,18 +2244,18 @@ long XFileExplorer::onCmdFileMan(FXObject*,FXSelector sel,void* ptr)
 	
     // File operation dialog, if needed
 	if(ask_before_copy || source==target ||  FXSELID(sel)==ID_FILE_COPYTO || FXSELID(sel)==ID_FILE_MOVE ||  FXSELID(sel)==ID_FILE_RENAME || FXSELID(sel)==ID_FILE_SYMLINK)
-	{
-    	InputDialog* dialog;
-    	dialog=new InputDialog(this,target,message,title,_("To:"),icon);
-    	dialog->CursorEnd();
-	    int rc=1;
-        rc=dialog->execute(PLACEMENT_CURSOR);
-	    target=dialog->getText();
+	{    	
+		InputDialog* dialog;
+		dialog=new InputDialog(this,target,message,title,_("To:"),icon);
+		dialog->CursorEnd();
+		int rc=1;
+		rc=dialog->execute(PLACEMENT_CURSOR);
+		target=dialog->getText();
 		delete dialog;
 		if (!rc)
 			return 0;
-	}    
-
+	}
+	
 	// Update target and target parent directory
 	target=::filePath(target);
 	if (!::isDirectory(target))
