@@ -20,10 +20,10 @@
 
 #include "xfedefs.h"
 #include "icons.h"
-#include "FileList.h"
 #include "FileDialog.h"
 #include "InputDialog.h"
 #include "MessageBox.h"
+#include "File.h"
 #include "XFileImage.h"
 
 // Add FOX hacks
@@ -34,6 +34,40 @@ char **args;
 FXColor listbackcolor, listforecolor;
 FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
+FXbool single_click_diropen=FALSE;
+FXbool single_click_fileopen=FALSE;
+
+// Hand cursor replacement
+#define hand_width 32
+#define hand_height 32
+#define hand_x_hot 6
+#define hand_y_hot 1
+ static const FXuchar hand_bits[] = {
+   0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00,
+   0x90, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90, 0x07, 0x00, 0x00,
+   0x97, 0x1a, 0x00, 0x00, 0x99, 0x2a, 0x00, 0x00, 0x11, 0x28, 0x00, 0x00,
+   0x12, 0x20, 0x00, 0x00, 0x02, 0x20, 0x00, 0x00, 0x02, 0x20, 0x00, 0x00,
+   0x04, 0x20, 0x00, 0x00, 0x04, 0x10, 0x00, 0x00, 0xf8, 0x0f, 0x00, 0x00,
+   0xf0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
+ 
+ static const FXuchar hand_mask_bits[] = {
+   0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00,
+   0xf0, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0xf0, 0x07, 0x00, 0x00,
+   0xf7, 0x1f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00,
+   0xfe, 0x3f, 0x00, 0x00, 0xfe, 0x3f, 0x00, 0x00, 0xfe, 0x3f, 0x00, 0x00,
+   0xfc, 0x3f, 0x00, 0x00, 0xfc, 0x1f, 0x00, 0x00, 0xf8, 0x0f, 0x00, 0x00,
+   0xf0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
+   
 
 // Predefined zoom factors 
 #define NB_ZOOM 24
@@ -83,7 +117,8 @@ FXDEFMAP(XFileImage) XFileImageMap[]={
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_QUIT,XFileImage::onCmdQuit),
                                         FXMAPFUNC(SEL_SIGNAL,XFileImage::ID_QUIT,XFileImage::onCmdQuit),
                                         FXMAPFUNC(SEL_CLOSE,XFileImage::ID_TITLE,XFileImage::onCmdQuit),
-                                        FXMAPFUNC(SEL_DOUBLECLICKED,XFileImage::ID_FILELIST,XFileImage::onCmdFileList),
+                                        FXMAPFUNC(SEL_DOUBLECLICKED,XFileImage::ID_FILELIST,XFileImage::onCmdItemDoubleClicked),
+                                        FXMAPFUNC(SEL_CLICKED,XFileImage::ID_FILELIST,XFileImage::onCmdItemClicked),
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_RECENTFILE,XFileImage::onCmdRecentFile),
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_HIDDEN,XFileImage::onCmdToggleHidden),
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_THUMBNAILS,XFileImage::onCmdToggleThumbnails),
@@ -118,6 +153,8 @@ FXDEFMAP(XFileImage) XFileImageMap[]={
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_HIDDEN,XFileImage::onUpdToggleHidden),
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_THUMBNAILS,XFileImage::onUpdToggleThumbnails),
                                			FXMAPFUNC(SEL_UPDATE,XFileImage::ID_LABEL,XFileImage::onUpdLabel),
+                                        FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_FIT_WIN,XFileImage::onCmdToggleFitWin),
+										FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_FIT_WIN,XFileImage::onUpdToggleFitWin),
                                     };
 
 
@@ -190,6 +227,10 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,8
 	filelist->setTextColor(listforecolor);
 	filelist->setBackColor(listbackcolor);
 
+	// Single click navigation
+	if (single_click_diropen & single_click_fileopen)
+		filelist->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+
     // Status bar
 	statusbar=new FXHorizontalFrame(fileframe,JUSTIFY_LEFT|LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 3,3,0,0);
     new FXToggleButton(statusbar,_("\tShow hidden files (Ctrl-F6)"),_("\tHide hidden files (Ctrl-F6)"),showhiddenicon,hidehiddenicon,this->filelist,
@@ -200,7 +241,6 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,8
 	new FXStatusBar(statusbar,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
 	new FXDragCorner(statusbar);
 
-
     // Toolbar button: Open file
     new FXButton(toolbar,_("\tOpen Image (Ctrl-O)\tOpen image file. (Ctrl-O)"),fileopenicon,this,ID_OPEN,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
 
@@ -282,6 +322,7 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,8
     // Preferences menu
     new FXMenuCheck(prefsmenu,_("&Toolbar\t\tDisplay toolbar."),toolbar,FXWindow::ID_TOGGLESHOWN);
     new FXMenuCheck(prefsmenu,_("&File list\t\tDisplay file list."),filebox,FXWindow::ID_TOGGLESHOWN);
+    new FXMenuCheck(prefsmenu,_("Fit &window when opening\t\tZoom to fit window when opening an image."),this,ID_TOGGLE_FIT_WIN);
 
     // View Menu entries
     new FXMenuCheck(viewmenu,_("&Hidden files\tCtrl-F6\tShow hidden files and directories. (Ctrl-F6)"),this,ID_TOGGLE_HIDDEN);
@@ -316,6 +357,7 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,8
 	// Initialize zoom to 100%
 	indZoom=ZOOM_100;
 	zoomval=zoomtab[indZoom];
+	fitwin=FALSE;
 }
 
 
@@ -456,8 +498,8 @@ FXbool XFileImage::loadimage(const FXString& file)
         getApp()->beginWaitCursor();
         img->loadPixels(stream);
         stream.close();
-
-    	if (!FXMEMDUP(&tmpdata,img->getData(),FXColor,img->getWidth()*img->getHeight()))
+		
+		if (!FXMEMDUP(&tmpdata,img->getData(),FXColor,img->getWidth()*img->getHeight()))
 			throw FXMemoryException(_("Unable to load image"));
 		tmpimg->setData(tmpdata,IMAGE_OWNED,img->getWidth(),img->getHeight());	
 
@@ -470,12 +512,35 @@ FXbool XFileImage::loadimage(const FXString& file)
 		indZoom=ZOOM_100;
 		zoomval=zoomtab[indZoom];
     	getApp()->endWaitCursor();
+		
+		// Zoom to fit window if asked
+		if (fitwin)
+			handle(this,FXSEL(SEL_COMMAND,ID_ZOOM_WIN),NULL);
     }
     filelist->setDirectory(FXPath::directory(file));
     return TRUE;
 }
 
 
+// Toggle zoom to fit window on startup
+long XFileImage::onCmdToggleFitWin(FXObject*,FXSelector,void*)
+{
+	fitwin=!fitwin;
+    return 1;
+}
+
+
+// Update toggle wrap mode
+long XFileImage::onUpdToggleFitWin(FXObject* sender,FXSelector,void*)
+{
+    if(fitwin)
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
+    else
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+    return 1;
+}
+
+
 
 // Open
 long XFileImage::onCmdOpen(FXObject*,FXSelector,void*)
@@ -695,13 +760,13 @@ long XFileImage::onCmdQuit(FXObject*,FXSelector,void*)
 }
 
 
-// Update title
+// Update title (display image size and actual zoom)
 long XFileImage::onUpdTitle(FXObject* sender,FXSelector,void*)
 {
     FXString title="Xfi " + filename;
     FXImage* image=imageview->getImage();
     if(image)
-        title+=" (" + FXStringVal(zoomval*100) + "%" ")";
+        title+=" (" + FXStringVal(img->getWidth()) + "x" + FXStringVal(img->getHeight()) + " - " + FXStringVal(zoomval*100) + "%" ")";
     sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SETSTRINGVALUE),(void*)&title);
     return 1;
 }
@@ -725,15 +790,23 @@ long XFileImage::onCmdRecentFile(FXObject*,FXSelector,void* ptr)
 }
 
 
-// Command from the tree list
-long XFileImage::onCmdFileList(FXObject*,FXSelector,void* ptr)
+// Double clicked in the file list
+long XFileImage::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
 {
     FXint index=(FXint)(FXival)ptr;
     if(0<=index)
     {
         if(filelist->isItemDirectory(index))
         {
-            filelist->setDirectory(filelist->getItemPathname(index));
+			FXString filepath=filelist->getItemPathname(index);
+
+			// Does not have access
+			if(!::isReadExecutable(filepath))
+			{
+				MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+				return 0;
+			}
+            filelist->setDirectory(filepath);
         }
         else if(filelist->isItemFile(index))
         {
@@ -746,6 +819,39 @@ long XFileImage::onCmdFileList(FXObject*,FXSelector,void* ptr)
 }
 
 
+// Single clicked in the file list
+long XFileImage::onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr)
+{
+	if (single_click_diropen | single_click_fileopen)
+	{		
+		FXint index=(FXint)(FXival)ptr;
+		if(0<=index)
+		{
+			if(single_click_diropen && filelist->isItemDirectory(index))
+			{
+				FXString filepath=filelist->getItemPathname(index);
+
+				// Does not have access
+				if(!::isReadExecutable(filepath))
+				{
+					MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+					return 0;
+				}
+				filelist->setDirectory(filepath);
+			}
+			else if(single_click_fileopen && filelist->isItemFile(index))
+			{
+				filename=filelist->getItemPathname(index);
+				mrufiles.appendFile(filename);
+				loadimage(filename);
+			}
+		}
+	}
+    return 1;
+}
+
+
+
 // Rotate image
 long XFileImage::onCmdRotate(FXObject*,FXSelector sel,void*)
 {
@@ -924,17 +1030,17 @@ long XFileImage::onCmdZoomWin(FXObject*,FXSelector,void*)
 	FXint h=img->getHeight();
 	
 	// Compute zoom factor
-	FXdouble zoomwin;	
+	FXdouble fitwin;	
 	if (FXdouble(w)/FXdouble(h)>FXdouble(winw)/FXdouble(winh))
-		zoomwin=0.98*(FXdouble)winw/(FXdouble)w;
+		fitwin=0.98*(FXdouble)winw/(FXdouble)w;
 	else
-		zoomwin=0.98*(FXdouble)winh/(FXdouble)h;
+		fitwin=0.98*(FXdouble)winh/(FXdouble)h;
 
 	// Find the most approaching predefined zoom
 	// This is used in other zoom functions
 	for (FXint k=0; k<NB_ZOOM; k++)
 	{
- 		if (zoomtab[k]>zoomwin)
+ 		if (zoomtab[k]>fitwin)
 		{	
 			indZoom=k-1;
 			break;
@@ -949,15 +1055,15 @@ long XFileImage::onCmdZoomWin(FXObject*,FXSelector,void*)
 	tmpimg->setData(tmpdata,IMAGE_OWNED,img->getWidth(),img->getHeight());	
 
 	// Resize the image according to the new zoom factor
-	FXint sx=(FXint)(w*zoomwin);
-	FXint sy=(FXint)(h*zoomwin);
+	FXint sx=(FXint)(w*fitwin);
+	FXint sy=(FXint)(h*fitwin);
 
 	// Scale image according to the new zoom factor
     tmpimg->scale(sx,sy,1);
     imageview->setImage(tmpimg);
 
 	// Set zoom value for window title
-	zoomval=zoomwin;
+	zoomval=fitwin;
 	
 	getApp()->endWaitCursor();
     return 1;
@@ -1015,6 +1121,9 @@ void XFileImage::create()
     iconview=getApp()->reg().readUnsignedEntry("SETTINGS","iconview",ID_COLS);
 	this->handle(this,FXSEL(SEL_COMMAND,iconview),NULL);
 
+	// Get startup zoom
+	fitwin=getApp()->reg().readUnsignedEntry("SETTINGS","fitwin",0);
+	
 	// Reposition window
     position(xx,yy,ww,hh);
 
@@ -1054,6 +1163,9 @@ void XFileImage::saveConfig()
 	getApp()->reg().writeUnsignedEntry("SETTINGS","fileview",fileview);
 	getApp()->reg().writeUnsignedEntry("SETTINGS","iconview",iconview);
 
+	// Startup zoom
+	getApp()->reg().writeUnsignedEntry("SETTINGS","fitwin",fitwin);
+
 	// Write registry settings
 	getApp()->reg().write();
 }
@@ -1085,8 +1197,8 @@ int main(int argc,char *argv[])
 	FXbool loadicons;
 
 #ifdef HAVE_SETLOCALE
-  // Set locale via LC_ALL.
-  setlocale (LC_ALL, "");
+	// Set locale via LC_ALL.
+	setlocale (LC_ALL, "");
 #endif
 
 #if ENABLE_NLS
@@ -1124,6 +1236,10 @@ int main(int argc,char *argv[])
     // Open display
     application->init(argc,argv);
 
+    // Redefine the default hand cursor
+    FXCursor* hand=new FXCursor(application,hand_bits,hand_mask_bits,hand_width,hand_height,hand_x_hot,hand_y_hot);
+    application->setDefaultCursor(DEF_HAND_CURSOR,hand);
+
 	// Load all application icons
 	loadicons=loadAppIcons(application);
 	
@@ -1158,6 +1274,10 @@ int main(int argc,char *argv[])
 	application->setSelforeColor(selforecolor);
 	application->setSelbackColor(selbackcolor);
 	application->setBorderColor(bordercolor);
+	
+	// Set single click navigation according to the Xfe registry
+	single_click_diropen=reg->readUnsignedEntry("OPTIONS","single_click_diropen",FALSE);
+	single_click_fileopen=reg->readUnsignedEntry("OPTIONS","single_click_fileopen",FALSE);
 
 	// Delete the Xfe registry
 	delete reg;
