@@ -31,7 +31,8 @@ protected:
 	FXImage			  *tmpimg;				  // Temporary image
     FXColor 		  *tmpdata;				  // Temporary image data
 	FXint			  indZoom;				  // Zoom index
-	FXdouble		  zoomval;				  // Actual zoom factor					
+	FXdouble		  zoomval;				  // Actual zoom factor
+	FXbool			  fitwin;                 // Fit window when opening an image
 protected:
     XFileImage()
     {}
@@ -47,7 +48,6 @@ public:
 	long onCmdSave(FXObject*,FXSelector,void*);
     long onCmdQuit(FXObject*,FXSelector,void*);
     long onUpdTitle(FXObject*,FXSelector,void*);
-    long onCmdFileList(FXObject*,FXSelector,void*);
     long onCmdRecentFile(FXObject*,FXSelector,void*);
     long onCmdRotate(FXObject*,FXSelector,void*);
     long onCmdMirror(FXObject*,FXSelector,void*);
@@ -63,6 +63,10 @@ public:
 	long onCmdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr);
 	long onUpdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr);
 	long onUpdLabel(FXObject*,FXSelector,void*);
+    long onCmdItemDoubleClicked(FXObject*,FXSelector,void*);
+	long onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr);
+	long onCmdToggleFitWin(FXObject*,FXSelector,void*);
+	long onUpdToggleFitWin(FXObject*,FXSelector,void*);
 public:
     enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -89,6 +93,7 @@ public:
         ID_ZOOM_OUT,
         ID_ZOOM_100,
         ID_ZOOM_WIN,
+		ID_TOGGLE_FIT_WIN,
         ID_LAST
     };
 public:
