@@ -1,6 +1,5 @@
-#include <fox-1.4/fx.h>
-#include <stdio.h>
-#include <string.h>
+#ifndef XFILEQUERY_H
+#define XFILEQUERY_H
 
 class XFileQuery : public FXMainWindow
 {
@@ -9,6 +8,7 @@ protected:
     FXMenuBar			*menubar;			// Menu bar
     FXMenuPane			*filemenu;			// File menu
     FXMenuPane			*helpmenu;			// Help menu
+    FXMenuPane			*prefsmenu;			// Preferences menu
     FXHorizontalFrame	*contents;			// Sunken border for text widget
     FXToolBar			*toolbar;			// Toolbar
     FXString 			filename;			// Current package name
@@ -16,9 +16,6 @@ protected:
     FXText 				*description;		// Package description
     FXbool 				desc_clean;			// Clean description flag
     FXbool 				list_clean;			// Clean list flag
-	FXIcon				*folder_open;		// Folder icon for file list
-	FXIcon				*folder_closed;		// Folder icon for file list
-	FXIcon				*doc;				// Document icon for file list
     XFileQuery()
     {}
 public:
@@ -26,7 +23,7 @@ public:
         ID_DESCRIPTION=FXMainWindow::ID_LAST,
         ID_FILELIST,
         ID_UNINSTALL,
-        ID_UPGRADE,
+        ID_INSTALL,
 		ID_ABOUT,
 		ID_OPEN,
         ID_QUIT,
@@ -35,8 +32,9 @@ public:
     void start(FXString startpkg);
     void create();
     XFileQuery(FXApp *a);
+	~XFileQuery();
     long onCmdUninstall(FXObject*,FXSelector,void*);
-    long onCmdUpgrade(FXObject*,FXSelector,void*);
+    long onCmdInstall(FXObject*,FXSelector,void*);
 	long onCmdAbout(FXObject*,FXSelector,void*);
 	long onCmdOpen(FXObject*,FXSelector,void*);
     long onUpdDescription(FXObject*,FXSelector,void*);
@@ -44,3 +42,5 @@ public:
 	void saveConfig();
     long onCmdQuit(FXObject*,FXSelector,void*);
 };
+
+#endif
