@@ -314,6 +314,200 @@ void FXIconItem::drawDetails(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXi
 }
 
 
+// The function below is taken from the FXIconList class
+// and hacked to allow single click navigation in the FileList
+// It replaces the normal function...
+
+#define SELECT_MASK   (ICONLIST_EXTENDEDSELECT|ICONLIST_SINGLESELECT|ICONLIST_BROWSESELECT|ICONLIST_MULTIPLESELECT)
+
+long FXIconList::onKeyPress(FXObject*,FXSelector,void* ptr)
+{
+    FXEvent* event=(FXEvent*)ptr;
+    FXint index=current;
+    flags&=~FLAG_TIP;
+    if(!isEnabled())
+		return 0;
+    if(target && target->tryHandle(this,FXSEL(SEL_KEYPRESS,message),ptr))
+		return 1;
+    switch(event->code)
+    {
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+        if(flags&FLAG_DODRAG)
+            handle(this,FXSEL(SEL_DRAGGED,0),ptr);
+        return 1;
+    case KEY_Page_Up:
+    case KEY_KP_Page_Up:
+        lookup=FXString::null;
+        setPosition(pos_x,pos_y+verticalScrollBar()->getPage());
+        return 1;
+    case KEY_Page_Down:
+    case KEY_KP_Page_Down:
+        lookup=FXString::null;
+        setPosition(pos_x,pos_y-verticalScrollBar()->getPage());
+        return 1;
+    case KEY_Right:
+    case KEY_KP_Right:
+        if(!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS)))
+        {
+            setPosition(pos_x-10,pos_y);
+            return 1;
+        }
+        if(options&ICONLIST_COLUMNS)
+			index+=1;
+        else
+			index+=nrows;
+        goto hop;
+    case KEY_Left:
+    case KEY_KP_Left:
+        if(!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS)))
+        {
+            setPosition(pos_x+10,pos_y);
+            return 1;
+        }
+        if(options&ICONLIST_COLUMNS)
+			index-=1;
+        else
+			index-=nrows;
+        goto hop;
+    case KEY_Up:
+    case KEY_KP_Up:
+        if(options&ICONLIST_COLUMNS)
+			index-=ncols;
+        else
+			index-=1;
+        goto hop;
+    case KEY_Down:
+    case KEY_KP_Down:
+        if(options&ICONLIST_COLUMNS)
+			index+=ncols;
+        else
+			index+=1;
+        goto hop;
+    case KEY_Home:
+    case KEY_KP_Home:
+        index=0;
+        goto hop;
+    case KEY_End:
+    case KEY_KP_End:
+        index=items.no()-1;
+hop:
+        lookup=FXString::null;
+        if(0<=index && index<items.no())
+        {
+            setCurrentItem(index,TRUE);
+            makeItemVisible(index);
+            if(items[index]->isEnabled())
+            {
+                if((options&SELECT_MASK)==ICONLIST_EXTENDEDSELECT)
+                {
+                    if(event->state&SHIFTMASK)
+                    {
+                        if(0<=anchor)
+                        {
+                            selectItem(anchor,TRUE);
+                            extendSelection(index,TRUE);
+                        }
+                        else
+                            selectItem(index,TRUE);
+                    }
+                    else if(!(event->state&CONTROLMASK))
+                    {
+                        killSelection(TRUE);
+                        selectItem(index,TRUE);
+                        setAnchorItem(index);
+                    }
+                }
+            }
+        }
+		
+		// !!!! Hack to allow single click navigation in the FileList 
+        //handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
+        // !!!! End of hack
+		
+		if(0<=current && items[current]->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
+        return 1;
+    case KEY_space:
+    case KEY_KP_Space:
+        lookup=FXString::null;
+        if(0<=current && items[current]->isEnabled())
+        {
+            switch(options&SELECT_MASK)
+            {
+            case ICONLIST_EXTENDEDSELECT:
+                if(event->state&SHIFTMASK)
+                {
+                    if(0<=anchor)
+                    {
+                        selectItem(anchor,TRUE);
+                        extendSelection(current,TRUE);
+                    }
+                    else
+                        selectItem(current,TRUE);
+                }
+                else if(event->state&CONTROLMASK)
+                    toggleItem(current,TRUE);
+                else
+                {
+                    killSelection(TRUE);
+                    selectItem(current,TRUE);
+                }
+                break;
+            case ICONLIST_MULTIPLESELECT:
+            case ICONLIST_SINGLESELECT:
+                toggleItem(current,TRUE);
+                break;
+            }
+            setAnchorItem(current);
+        }
+        handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
+        if(0<=current && items[current]->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
+        return 1;
+    case KEY_Return:
+    case KEY_KP_Enter:
+        lookup=FXString::null;
+        handle(this,FXSEL(SEL_DOUBLECLICKED,0),(void*)(FXival)current);
+        if(0<=current && items[current]->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
+        return 1;
+    default:
+        if((FXuchar)event->text[0]<' ')
+			return 0;
+        if(event->state&(CONTROLMASK|ALTMASK))
+			return 0;
+        if(!Ascii::isPrint(event->text[0]))
+			return 0;
+        lookup.append(event->text);
+        getApp()->addTimeout(this,ID_LOOKUPTIMER,getApp()->getTypingSpeed());
+        index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
+        if(0<=index)
+        {
+            setCurrentItem(index,TRUE);
+            makeItemVisible(index);
+            if(items[index]->isEnabled())
+            {
+                if((options&SELECT_MASK)==ICONLIST_EXTENDEDSELECT)
+                {
+                    killSelection(TRUE);
+                    selectItem(index,TRUE);
+                }
+                setAnchorItem(index);
+            }
+        }
+        handle(this,FXSEL(SEL_CLICKED,0),(void*)(FXival)current);
+        if(0<=current && items[current]->isEnabled())
+            handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
+        return 1;
+    }
+    return 0;
+}
+
 
 // Move content
 void FXIconList::moveContents(FXint x,FXint y)
